<?php

namespace backend\modules\career\models\search;

use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\modules\career\models\Vacancy;
use yii\db\Expression;
use yii\db\Query;

/**
 * VacancySearch represents the model behind the search form about `backend\modules\career\models\Vacancy`.
 */
class VacancySearch extends Vacancy
{


    public $sort_by = 'published_at';

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id', 'status', 'job_level_id', 'job_field_id', 'employee_status_id', 'location_id',
                'expire_date', 'created_at', 'updated_at', 'created_by', 'updated_by', 'revision', 'schedule_id'], 'integer'],
            [['slug', 'image_header', 'main_category', 'view', 'layout'], 'safe'],
            ['published_at', 'date', 'timestampAttribute' => 'published_at', 'format' => 'yyyy-MM-dd'],
            [['title', 'sort_by'], 'string']

        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params, $withExpired = true)
    {
        $query = Vacancy::find()->joinWith('translation');

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => Yii::$app->request->cookies->getValue('_grid_page_size', 20),
            ],
//            'sort' => [
//                'defaultOrder' => [
//                    'id' => SORT_DESC,
//                ],
//            ],
        ]);
        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        $query->andFilterWhere([
            'id' => $this->id,
            'status' => $this->status,
            'job_level_id' => $this->job_level_id,
            'job_field_id' => $this->job_field_id,
            'employee_status_id' => $this->employee_status_id,
            'location_id' => $this->location_id,
            'expire_date' => $this->expire_date,
            'published_at' => $this->published_at,
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
            'created_by' => $this->created_by,
            'updated_by' => $this->updated_by,
            'revision' => $this->revision,
            'schedule_id' => $this->schedule_id,
            'main_category' => $this->main_category,
        ]);

        $query
            ->andFilterWhere(['like', 'image_header', $this->image_header])
            ->andFilterWhere(['like', 'view', $this->view])
            ->andFilterWhere(['like', 'layout', $this->layout]);

        $query->andFilterWhere(['or', ['like', 'title', $this->title], ['like', 'content', $this->title]]);


        if (!$withExpired)
            $query->andFilterWhere(['>=', 'published_at', new Expression('(UNIX_TIMESTAMP(DATE(NOW() - INTERVAL 30 DAY)))')]);

        //to convert int to date format use in search
        if ($this->published_at) {
            $this->published_at = date('Y-m-d', $this->published_at);
        }

        //because join
        $query->groupBy(['vacancy.id']);

//var_dump($this->sort_by);die();
        if ($this->sort_by) {
            switch ($this->sort_by) {
                case 'published_at_desc':
                    $query->orderBy(['published_at' => SORT_DESC]);
                    break;
                case 'published_at_asc':
                    $query->orderBy(['published_at' => SORT_ASC]);
                    break;
                default:
                    $query->orderBy(['published_at' => SORT_DESC]);

            }
        }

//        var_dump($query->createCommand()->rawSql);
        return $dataProvider;
    }

    public static function getNumberOfVacancyPerType($category)
    {
        $params = [];
        $params['VacancySearch']['main_category'] = $category;
        $searchModel = new self();

        return $searchModel->search($params, false)->count;
    }
}
