<?php

use backend\modules\district\models\District;
use backend\modules\dropdown_list\models\DropdownList;
use common\helpers\Utility;
use kartik\widgets\Select2;
use yeesoft\widgets\ActiveForm;
use backend\modules\career\models\Vacancy;
use yeesoft\helpers\Html;
use yii\helpers\ArrayHelper;
use yii\jui\DatePicker;
use yeesoft\models\User;

/* @var $this yii\web\View */
/* @var $model backend\modules\career\models\Vacancy */
/* @var $form yeesoft\widgets\ActiveForm */
?>

<div class="vacancy-form">

    <?php 
    $form = ActiveForm::begin([
            'id' => 'vacancy-form',
            'validateOnBlur' => false,
        ]);
    //TO FORCE update slug
    echo $form->field($model, 'slug')->label(false)->hiddenInput(['maxlength' => true, 'value' => '']);
    ?>

    <?= $form->errorSummary($model, ['class' => 'alert alert-danger']); ?>


    <div class="row">
        <div class="col-md-8">

            <div class="panel panel-default">
                <div class="panel-body">

                    <?php if ($model->isMultilingual()): ?>
                        <?= \yeesoft\widgets\LanguagePills::widget() ?>
                    <?php endif; ?>

                    <?= $form->field($model, 'title')->textInput() ?>
                    <?= $form->field($model, 'brief')->textInput() ?>

                    <?= $form->field($model, 'content')->widget(\yeesoft\media\widgets\TinyMce::className(), [
                        'clientOptions' => [
                            'height' => 400,
                            'image_dimensions' => true,
                            'entity_encoding' => 'raw',
                            'plugins' => [
                                'directionality fullpage code print preview searchreplace autolink directionality visualblocks visualchars fullscreen image link media template codesample table charmap hr pagebreak nonbreaking anchor toc insertdatetime advlist lists textcolor wordcount imagetools   contextmenu colorpicker textpattern',
                            ],
                            'toolbar' => 'undo redo | styleselect fontsizeselect bold italic | ltr rtl | alignleft aligncenter alignright alignjustify bullist numlist outdent indent | pagebreak link image table | forecolor backcolor | removeformat | code',

                        ]
                    ]); ?>

                </div>

            </div>
        </div>

        <div class="col-md-4">

            <div class="panel panel-default">
                <div class="panel-body">
                    <div class="record-info">

                        <?php if (!$model->isNewRecord): ?>
                            <div class="form-group clearfix">
                                <label class="control-label" style="float: left; padding-right: 5px;"><?=  $model->attributeLabels()['id'] ?>: </label>
                                <span><?=  $model->id ?></span>
                            </div>

                            <div class="form-group clearfix">
                                <label class="control-label" style="float: left; padding-right: 5px;">
                                    <?= $model->attributeLabels()['slug'] ?> :
                                </label>
                                <span><?= $model->slug ?></span>
                            </div>

                            <div class="form-group clearfix">
                                <label class="control-label" style="float: left; padding-right: 5px;">
                                    <?= $model->attributeLabels()['created_at'] ?> :
                                </label>
                                <span><?= $model->createdDatetime ?></span>
                            </div>

                            <div class="form-group clearfix">
                                <label class="control-label" style="float: left; padding-right: 5px;">
                                    <?= $model->attributeLabels()['updated_at'] ?> :
                                </label>
                                <span><?= $model->updatedDatetime ?></span>
                            </div>

                            <div class="form-group clearfix">
                                <label class="control-label" style="float: left; padding-right: 5px;">
                                    <?= $model->attributeLabels()['updated_by'] ?> :
                                </label>
                                <span><?= $model->updatedBy->username ?></span>
                            </div>

                        <?php endif; ?>

                        <div class="form-group">
                            <?php  if ($model->isNewRecord): ?>
                                <?= Html::submitButton(Yii::t('yee', 'Create'), ['class' => 'btn btn-primary']) ?>
                                <?= Html::a(Yii::t('yee', 'Cancel'), ['/vacancy/default/index'], ['class' => 'btn btn-default']) ?>
                            <?php  else: ?>
                                <?= Html::submitButton(Yii::t('yee', 'Save'), ['class' => 'btn btn-primary']) ?>
                                <?= Html::a(Yii::t('yee', 'Delete'),
                                    ['/vacancy/default/delete', 'id' => $model->id], [
                                    'class' => 'btn btn-default',
                                    'data' => [
                                        'confirm' => Yii::t('yii', 'Are you sure you want to delete this item?'),
                                        'method' => 'post',
                                    ],
                                ]) ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>

            <div class="panel panel-default">
                <div class="panel-body">

                    <div class="record-info">

                        <?php  $form->field($model, 'main_category')->widget(Select2::className(), [
                            'options' => ['placeholder' => 'Select ...'],
                            'pluginOptions' => [
                                'allowClear' => true
                            ],
                            'data' => Utility::$VACANCY_MAIN_CATEGORY
                        ]) ?>

                        <?php  $form->field($model, 'location_id')->widget(Select2::className(), [
                            'options' => ['placeholder' => 'Select ...'],
                            'pluginOptions' => [
                                'allowClear' => true
                            ],
                            'data' => ArrayHelper::map(District::find()->where(['status' => 1])->all(), 'id', 'title')
                        ]) ?>


                        <?php  $form->field($model, 'employee_status_id')->widget(Select2::className(), [
                            'options' => ['placeholder' => 'Select ...'],
                            'pluginOptions' => [
                                'allowClear' => true
                            ],
                            'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::EmployeeStatus])->all(), 'id', 'title')
                        ]) ?>

                        <?php echo $form->field($model, 'job_field_id')->widget(Select2::className(), [
                            'options' => ['placeholder' => 'Select ...'],
                            'pluginOptions' => [
                                'allowClear' => true
                            ],
                            'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::JobTileField])->all(), 'id', 'title')
                        ]) ?>

                        <?php echo $form->field($model, 'job_level_id')->widget(Select2::className(), [
                            'options' => ['placeholder' => 'Select ...'],
                            'pluginOptions' => [
                                'allowClear' => true
                            ],
                            'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::JobTileLevel])->all(), 'id', 'title')
                        ]) ?>

                        <?php  $form->field($model, 'schedule_id')->widget(Select2::className(), [
                            'options' => ['placeholder' => 'Select ...'],
                            'pluginOptions' => [
                                'allowClear' => true
                            ],
                            'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::Schedule])->all(), 'id', 'title')
                        ]) ?>


                        <?=
                        $form->field($model, 'published_at')
                            ->widget(DatePicker::className(), ['dateFormat' => 'yyyy-MM-dd', 'options' => ['class' => 'form-control']]);
                        ?>

                        <?= $form->field($model, 'status')->dropDownList(\common\helpers\Utility::getStatusList()) ?>

                        <?php if (!$model->isNewRecord): ?>
                            <?= $form->field($model, 'created_by')->dropDownList(User::getUsersList()) ?>
                        <?php endif; ?>
                        

                        <?= $form->field($model, 'image_header')->widget(yeesoft\media\widgets\FileInput::className(), [
                            'name' => 'image_header',
                            'buttonTag' => 'button',
                            'buttonName' => Yii::t('yee', 'Browse'),
                            'buttonOptions' => ['class' => 'btn btn-default btn-file-input'],
                            'options' => ['class' => 'form-control'],
                            'template' => '<div class="vacancy-image_header thumbnail"></div><div class="input-group">{input}<span class="input-group-btn">{button}</span></div>',
                            //'thumb' => $this->context->module->thumbnailSize,
                            'imageContainer' => '.vacancy-image_header',
                            'pasteData' => yeesoft\media\widgets\FileInput::DATA_URL,
                            'callbackBeforeInsert' => 'function(e, data) {
                                $(".vacancy-image_header").show();
                            }',
                        ]) ?>
                    </div>
                </div>
            </div>

        </div>
    </div>

    <?php  ActiveForm::end(); ?>

</div>



<?php


$js = <<<JS
    var image = $("#vacancy-image_header").val();
    if(image.length == 0){
        $('.vacancy-image_header').hide();
    } else {
        $('.vacancy-image_header').html('<img src="' + image + '" />');
    }

JS;

$this->registerJs($js, yii\web\View::POS_END);
?>