<?php

use common\models\User;
use yii\helpers\Url;
use yii\widgets\Pjax;
use yeesoft\grid\GridView;
use yeesoft\grid\GridQuickLinks;
use backend\modules\career\models\RecruitmentGuidance;
use yeesoft\helpers\Html;
use yeesoft\grid\GridPageSize;

/* @var $this yii\web\View */
/* @var $searchModel backend\modules\career\models\search\RecruitmentGuidanceSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = 'Recruitment Guidance';
$this->params['breadcrumbs'][] = $this->title;
?>
<div class="recruitment-guidance-index">

    <div class="row">
        <div class="col-sm-12">
            <h3 class="lte-hide-title page-title"><?=  Html::encode($this->title) ?></h3>
            <?= Html::a(Yii::t('yee', 'Add New'), ['/career/guidance/create'], ['class' => 'btn btn-sm btn-primary']) ?>
        </div>
    </div>

    <div class="panel panel-default">
        <div class="panel-body">

            <div class="row">
                <div class="col-sm-6">
                    <?php 
                    /* Uncomment this to activate GridQuickLinks */
                    /* echo GridQuickLinks::widget([
                        'model' => RecruitmentGuidance::className(),
                        'searchModel' => $searchModel,
                    ])*/
                    ?>
                </div>

                <div class="col-sm-6 text-right">
                    <?=  GridPageSize::widget(['pjaxId' => 'recruitment-guidance-grid-pjax']) ?>
                </div>
            </div>

            <?php 
            Pjax::begin([
                'id' => 'recruitment-guidance-grid-pjax',
            ])
            ?>

            <?php
            try {
                echo GridView::widget([
                    'id' => 'recruitment-guidance-grid',
                    'dataProvider' => $dataProvider,
                    'filterModel' => $searchModel,
                    'bulkActionOptions' => [
                        'gridId' => 'recruitment-guidance-grid',
                        'actions' => [
                            Url::to(['bulk-activate']) => Yii::t('yee', 'Publish'),
                            Url::to(['bulk-deactivate']) => Yii::t('yee', 'Unpublish'),
                            Url::to(['bulk-delete']) => Yii::t('yii', 'Delete'),
                        ]
                    ],
                    'columns' => [
                        ['class' => 'yeesoft\grid\CheckboxColumn', 'options' => ['style' => 'width:10px']],
                        [
                            'class' => 'yeesoft\grid\columns\TitleActionColumn',
                            'controller' => '/career/guidance',
                            'title' => function (RecruitmentGuidance $model) {
                                return Html::a($model->title, ['view', 'id' => $model->id], ['data-pjax' => 0]);
                            },
                        ],
                        [
                            'attribute' => 'created_by',
                            'filter' => User::getUsersList(),
                            'value' => function (RecruitmentGuidance $model) {
                                return Html::a($model->author->username,
                                    ['/user/default/update', 'id' => $model->created_by],
                                    ['data-pjax' => 0]);
                            },
                            'format' => 'raw',
                            'visible' => User::hasPermission('viewUsers'),
                            'options' => ['style' => 'width:180px'],
                        ],
                        [
                            'class' => 'yeesoft\grid\columns\StatusColumn',
                            'attribute' => 'status',
                            'optionsArray' => \common\helpers\Utility::getStatusOptionsList(),
                            'options' => ['style' => 'width:60px'],
                        ],
//                        [
//                            'class' => 'yeesoft\grid\columns\DateFilterColumn',
//                            'attribute' => 'published_at',
//                            'value' => function (Page $model) {
//                                return '<span style="font-size:85%;" class="label label-'
//                                    . ((time() >= $model->published_at) ? 'primary' : 'default') . '">'
//                                    . $model->publishedDate . '</span>';
//                            },
//                            'format' => 'raw',
//                            'options' => ['style' => 'width:150px'],
//                        ],
                    ],
                ]);
            } catch (Exception $e) {
                var_dump($e->getMessage());
            }
            ?>

            <?php Pjax::end() ?>
        </div>
    </div>
</div>


