<?php

namespace backend\modules\dropdown_list\models;

use backend\modules\career\models\RecruitmentGuidanceDropdownList;
use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\db\ActiveRecord;
use yeesoft\models\User;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\SluggableBehavior;
use yii\behaviors\TimestampBehavior;
use yii\helpers\Html;

/**
 * This is the model class for table "dropdown_list".
 *
 * @property int $id
 * @property int $created_at
 * @property int $updated_at
 * @property int $created_by
 * @property int $updated_by
 * @property string $url
 * @property string $icon
 * @property string $color_code
 *
 */
class DropdownList extends ActiveRecord
{

    const STATUS_PENDING = 0;
    const STATUS_PUBLISHED = 1;

    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'dropdown_list';
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            TimestampBehavior::className(),
            BlameableBehavior::className(),
            'sluggable' => [
                'class' => SluggableBehavior::className(),
                'attribute' => 'title',
            ],
            'multilingual' => [
                'class' => MultilingualBehavior::className(),
                'langForeignKey' => 'parent_id',
                'tableName' => "{{%dropdown_list_lang}}",
                'attributes' => [
                    'title',
                ]
            ],
        ];
    }


    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['title', 'category','status'], 'required'],
            [['created_by', 'updated_by'], 'integer'],
            [['title', 'category', 'icon','color_code'], 'string', 'max' => 255],
            [['created_at', 'updated_at','parent_id'], 'safe'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'published_at' => Yii::t('site', 'Published At'),
            'created_at' => Yii::t('site', 'Created At'),
            'updated_at' => Yii::t('site', 'Updated At'),
            'created_by' => Yii::t('site', 'Created By'),
            'updated_by' => Yii::t('site', 'Updated By'),

        ];
    }

    /**
     * {@inheritdoc}
     * @return DropdownListQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new DropdownListQuery(get_called_class());
    }


    /**
     * @return string
     */
    public function __toString()
    {
        return $this->title;
    }


    public function getAuthor()
    {
        return $this->hasOne(User::className(), ['id' => 'created_by']);
    }

    public function getUpdatedBy()
    {
        return $this->hasOne(User::className(), ['id' => 'updated_by']);
    }

    public function getCreatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getCreatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedDatetime()
    {
        return "{$this->publishedDate} {$this->publishedTime}";
    }

    public function getCreatedDatetime()
    {
        return "{$this->createdDate} {$this->createdTime}";
    }

    public function getUpdatedDatetime()
    {
        return "{$this->updatedDate} {$this->updatedTime}";
    }

    /**
     * getTypeList
     * @return array
     */
    public static function getStatusList()
    {
        return [
            self::STATUS_PENDING => Yii::t('site', 'Pending'),
            self::STATUS_PUBLISHED => Yii::t('site', 'Published'),
        ];
    }


    const VehicleColors = 'VehicleColors';
    const VehicleInteriorColor = 'VehicleInteriorColor';

    const VehicleBodyType = 'VehicleBodyType';
    const VehicleCylinders = 'VehicleCylinders';
    const VehicleEngine = 'VehicleEngine';
    const VehicleTransmission = 'VehicleTransmission';
    const VehicleDrive = 'VehicleDrive';
    const VehicleManufacturer = 'VehicleManufacturer';
    const VehicleModelManufacturer = 'VehicleModelManufacturer';
    const VehicleEquipments = 'VehicleEquipments';
    const VehicleAttachments = 'VehicleAttachments';
    const VehicleRemarks = 'VehicleRemarks';
    const VehicleOwnerType = 'VehicleOwnerType';
    const MeasuringTheDistance = 'MeasuringTheDistance';
    const ContactUsCategory = 'ContactUsCategory';

    /**
     * getTypeList
     * @return array
     */
    public static function getCategoryList()
    {
        return [
            '' => Yii::t('site', ''),
            self::VehicleColors => Yii::t('site', 'VehicleColors'),
            self::VehicleInteriorColor => Yii::t('site', 'VehicleInteriorColor'),
            self::VehicleBodyType => Yii::t('site', 'VehicleBodyType'),
            self::VehicleEngine => Yii::t('site', 'VehicleEngine'),
            self::VehicleCylinders => Yii::t('site', 'VehicleCylinders'),
            self::VehicleTransmission => Yii::t('site', 'VehicleTransmission'),
            self::VehicleDrive => Yii::t('site', 'VehicleDrive'),
            self::VehicleManufacturer => Yii::t('site', 'VehicleManufacturer'),
            self::VehicleEquipments => Yii::t('site', 'VehicleEquipments'),
            self::VehicleAttachments => Yii::t('site', 'VehicleAttachments'),
            self::VehicleRemarks => Yii::t('site', 'VehicleRemarks'),
            self::VehicleManufacturer => Yii::t('site', 'VehicleManufacturer'),
            self::VehicleModelManufacturer => Yii::t('site', 'VehicleModelManufacturer'),
            self::VehicleOwnerType => Yii::t('site', 'VehicleOwnerType'),
            self::MeasuringTheDistance => Yii::t('site', 'MeasuringTheDistance'),
            self::ContactUsCategory => Yii::t('site', 'ContactUsCategory'),
        ];
    }


    /**
     *
     * @inheritdoc
     */
    public static function getFullAccessPermission()
    {
        return 'fullPageAccess';
    }

    /**
     *
     * @inheritdoc
     */
    public static function getOwnerField()
    {
        return 'created_by';
    }
    public function getData(){
      return '<img src="'. $this->icon.'"><span style="margin: 8px"></span><span></span><span>'.Yii::t('site',$this->title).'</span>';
    }

    public function getBodyColor(){
        return ' <div class="row bodyType">
                                                                                                                      <div class="form-group col-xl-9">
                                    <span class="square-color" style="background-color: '.$this->color_code.';border:1px solid #ccc" href=""></span><span style="margin-left: 10px">'.Yii::t('site',$this->title).'</span></div></div>';
    }
    public function getManufacturerData(){
        return Yii::t('site',$this->title);
    }
    public function getLanguageData(){
        return Yii::t('site',$this->title);
    }
}
