<?php

use backend\modules\dropdown_list\models\DropdownList;
use wbraganca\dynamicform\DynamicFormWidget;
use yeesoft\widgets\ActiveForm;
use common\models\User;
use yeesoft\helpers\Html;
use yii\helpers\ArrayHelper;
use yii\jui\DatePicker;

/* @var $this yii\web\View */
/* @var $model backend\modules\general_question\models\GeneralQuestion */
/* @var $form yeesoft\widgets\ActiveForm */


$js = '
jQuery(".dynamicform_wrapper").on("afterInsert", function(e, item) {
    jQuery(".dynamicform_wrapper .panel-title-member").each(function(index) {
        jQuery(this).html("Question: " + (index + 1))
    });
});

jQuery(".dynamicform_wrapper").on("afterDelete", function(e) {
    jQuery(".dynamicform_wrapper .panel-title-member").each(function(index) {
        jQuery(this).html("Question: " + (index + 1))
    });
});
';

$this->registerJs($js);


?>

<div class="general-question-form">

    <?php 
    $form = ActiveForm::begin([
            'id' => 'general-question-form',
            'validateOnBlur' => false,
        ])
    ?>
    <?= $form->errorSummary($model, ['class' => 'alert alert-danger']); ?>

    <div class="row">
        <div class="col-md-8">

            <div class="panel panel-default">
                <div class="panel-body">

                    <?= $form->field($model, 'name')->textInput(['maxlength' => true]) ?>

                    <?php //Dynamic Items ?>

                    <?php DynamicFormWidget::begin([
                        'widgetContainer' => 'dynamicform_wrapper', // required: only alphanumeric characters plus "_" [A-Za-z0-9_]
                        'widgetBody' => '.container-items', // required: css class selector
                        'widgetItem' => '.item', // required: css class
                        'limit' => 999, // the maximum times, an element can be cloned (default 999)
                        'min' => 1, // 0 or 1 (default 1)
                        'insertButton' => '.add-item', // css class
                        'deleteButton' => '.remove-item', // css class
                        'model' => $model->questionItems[0],
                        'formId' => 'general-question-form',
                        'formFields' => [
                            'first_name_ar',
                        ],
                    ]); ?>
                    <div class="panel panel-default">
                        <div class="panel-heading">
                            <h3 class="panel-title"><?= Yii::t('site', 'Questions') ?></h3>
                        </div>
                        <div class="panel-body container-items"><!-- widgetContainer -->
                            <?php foreach ($model->questionItems as $index => $modelItem): ?>
                                <div class="item panel panel-default"><!-- widgetBody -->
                                    <div class="panel-heading">
                                    <span class="panel-title-member"><?= Yii::t('site', 'Question') ?>
                                        : <?= ($index + 1) ?></span>
                                        <button type="button" class="pull-right remove-item btn btn-danger btn-xs"><i
                                                    class="fa fa-minus"></i></button>
                                        <div class="clearfix"></div>
                                    </div>
                                    <div class="panel-body">
                                        <?php
                                        $modelItem->detachBehavior('multilingual');

                                        // necessary for update action.
                                        if (!$model->isNewRecord) {
                                            echo Html::activeHiddenInput($modelItem, "[{$index}]id");
                                        }
                                        ?>
                                        <?= $form->field($modelItem, "[{$index}]q_en")->textInput(['maxlength' => true]) ?>
                                        <?= $form->field($modelItem, "[{$index}]q_ar")->textInput(['maxlength' => true]) ?>
                                        <?= $form->field($modelItem, "[{$index}]correct_answer")->dropDownList(['' => '', 'YES' => 'Yes', 'NO' => 'No']) ?>
                                        <?= $form->field($modelItem, "[{$index}]status")->dropDownList(\common\helpers\Utility::getStatusList()) ?>
                                    </div>

                                </div>
                            <?php endforeach; ?>
                        </div>
                        <div class="panel-footer">
                            <button type="button" class="pull-right add-item btn btn-success btn-xs"><i
                                        class="fa fa-plus"></i> <?= Yii::t('site', 'Add More') ?>
                            </button>
                            <div class="clearfix"></div>
                        </div>

                    </div>
                    <?php DynamicFormWidget::end(); ?>

                </div>

            </div>
        </div>


        <div class="col-md-4">

            <div class="panel panel-default">
                <div class="panel-body">
                    <div class="record-info">
                        <?php if (!$model->isNewRecord): ?>

                            <div class="form-group clearfix">
                                <label class="control-label" style="float: left; padding-right: 5px;">
                                    <?= $model->attributeLabels()['created_at'] ?> :
                                </label>
                                <span><?= $model->createdDatetime ?></span>
                            </div>

                            <div class="form-group clearfix">
                                <label class="control-label" style="float: left; padding-right: 5px;">
                                    <?= $model->attributeLabels()['updated_at'] ?> :
                                </label>
                                <span><?= $model->updatedDatetime ?></span>
                            </div>

                            <div class="form-group clearfix">
                                <label class="control-label" style="float: left; padding-right: 5px;">
                                    <?= $model->attributeLabels()['updated_by'] ?> :
                                </label>
                                <span><?= $model->updatedBy->username ?></span>
                            </div>

                        <?php endif; ?>

                        <div class="form-group">
                            <?php if ($model->isNewRecord): ?>
                                <?= Html::submitButton(Yii::t('site', 'Create'), ['class' => 'btn btn-primary']) ?>
                                <?= Html::a(Yii::t('site', 'Cancel'), ['/general_question/default/index'], ['class' => 'btn btn-default',]) ?>
                            <?php else: ?>
                                <?= Html::submitButton(Yii::t('site', 'Save'), ['class' => 'btn btn-primary']) ?>
                                <?=
                                Html::a(Yii::t('site', 'Delete'), ['/general_question/default/delete', 'id' => $model->id], [
                                    'class' => 'btn btn-default',
                                    'data' => [
                                        'confirm' => Yii::t('yii', 'Are you sure you want to delete this item?'),
                                        'method' => 'post',
                                    ],
                                ])
                                ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>

            <div class="panel panel-default">
                <div class="panel-body">

                    <div class="record-info">

                        <?=
                        $form->field($model, 'main_category')->dropDownList(\common\helpers\Utility::$VACANCY_MAIN_CATEGORY)
                        ?>
                        <?= $form->field($model, 'doctor_speciality_id')->widget(\kartik\select2\Select2::className(), [
                            'pluginOptions' => [
                                'allowClear' => true
                            ],
                            'options' => [
                                'placeholder' => Yii::t('site', 'Job field'),
                            ],
                            'data' => ArrayHelper::map(DropdownList::find()->where(['status' => true, 'category' => DropdownList::JobTileField])->all(), 'id', 'title')

                        ]) ?>

                        <?= $form->field($model, 'minimum_score')->textInput() ?>

                        <?=
                        $form->field($model, 'status')->dropDownList(\common\helpers\Utility::getStatusList())
                        ?>

                        <?php if (!$model->isNewRecord): ?>
                            <?= $form->field($model, 'created_by')->dropDownList(User::getUsersList()) ?>
                        <?php endif; ?>

                    </div>
                </div>
            </div>


        </div>

    </div>

    <?php  ActiveForm::end(); ?>

</div>
