<?php

namespace backend\modules\network\models\search;

use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\modules\network\models\Network;

/**
 * NetworkSearch represents the model behind the search form about `backend\modules\network\models\Network`.
 */
class NetworkSearch extends Network
{
    public $published_at_operand;


    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id', 'status', 'created_by', 'updated_by', 'revision'], 'integer'],
            [['sub_district', 'phone', 'fax', 'email', 'view', 'layout', 'published_at_operand', 'name', 'published_at', 'created_at', 'updated_at', 'city', 'category'], 'safe'],
            [['latitude', 'longitude'], 'number'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = Network::find()->joinWith('translations');

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => Yii::$app->request->cookies->getValue('_grid_page_size', 20),
            ],
            'sort' => false
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        $query->andWhere(['language' => 'ar']);

        $query->andFilterWhere([
            'id' => $this->id,
            'status' => $this->status,
            'latitude' => $this->latitude,
            'longitude' => $this->longitude,
            'published_at' => $this->published_at,
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
            'created_by' => $this->created_by,
            'updated_by' => $this->updated_by,
            'revision' => $this->revision,
            'category' => $this->category,
            'city' => $this->city,
            'sub_district' => $this->sub_district,
        ]);

        $query->andFilterWhere(['like', 'phone', $this->phone])
//            ->andFilterWhere(['like', 'address', $this->address])
            ->andFilterWhere(['like', 'name', $this->name])
            ->andFilterWhere(['like', 'fax', $this->fax])
            ->andFilterWhere(['like', 'email', $this->email])
            ->andFilterWhere(['like', 'view', $this->view])
            ->andFilterWhere(['like', 'layout', $this->layout]);

        return $dataProvider;
    }
}
