<?php

namespace backend\modules\newsletter\models;

use Yii;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "newsletter_client_list".
 *
 * @property int $id
 * @property string $full_name
 * @property string $email
 * @property int $city_id
 * @property int $phone
 * @property int $created_at
 * @property int $updated_at
 * @property int $confirmed
 */
class NewsletterClientList extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'newsletter_client_list';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            ['email', 'required'],
            [['phone', 'created_at', 'updated_at', 'confirmed', 'city_id'], 'integer'],
            [['email', 'full_name'], 'string', 'max' => 256],
            ['email', 'email', 'message' => Yii::t('site', 'Invalid email address')],
            [['email'], 'unique', 'message' => Yii::t('site', 'You are already subscribed to our newsletter')],
        ];
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            TimestampBehavior::className(),
        ];
    }


    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'full_name' => Yii::t('site', 'Full Name'),
            'email' => Yii::t('site', 'Email'),
            'phone' => Yii::t('site', 'Phone'),
            'city_id' => Yii::t('site', 'City'),
            'created_at' => Yii::t('site', 'Created At'),
            'updated_at' => Yii::t('site', 'Updated At'),
        ];
    }

    /**
     * {@inheritdoc}
     * @return NewsletterClientListQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new NewsletterClientListQuery(get_called_class());
    }

    public function getCreatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getCreatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getCreatedDatetime()
    {
        return "{$this->createdDate} {$this->createdTime}";
    }


    /**
     * Sends an email to the specified email address using the information collected by this model.
     *
     * @param  string $email the target email address
     * @return boolean whether the email was sent
     */
    public function sendEmail($email)
    {
        //echo Yii::$app->params['adminEmail'];exit;
        return Yii::$app->mailer->compose(
            ['html' => 'newsletter-confirmation'], ['email' => $email]
        )
            ->setTo($email)
            ->setFrom('admin@autostudio.jo')
            ->setSubject('Newsletter Subscribe')
            ->send();
    }
}
