<?php

namespace backend\modules\orders\models;

use bedezign\yii2\audit\AuditTrailBehavior;
use kartik\detail\DetailView;
use Yii;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "order".
 *
 * @property int $id
 * @property string $status
 * @property int $bill_id
 * @property int $created_at
 * @property int $updated_at
 * @property int $created_by
 * @property int $updated_by
 * @property string $first_name
 * @property string $last_name
 * @property string $mobile
 * @property string $email
 * @property string $city
 * @property string $address_line_1
 * @property string $address_line_2
 * @property string $reference_number
 * @property string $total_price
 * @property string $fees
 * @property string $shipping_price
 *
 * @property OrderItem[] $orderItems
 */
class Order extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'order';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['created_at', 'updated_at', 'created_by', 'updated_by', 'bill_id'], 'integer'],
            [['total_price', 'shipping_price', 'fees'], 'number'],
            [['status'], 'string', 'max' => 10],
            [['email'], 'email'],
            [['reference_number'], 'string', 'max' => 255],
            [['email', 'first_name', 'last_name', 'mobile'], 'required'],
            [['address_line_1', 'address_line_2'], 'required', 'on' => ['shipping']],

        ];
    }


    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            TimestampBehavior::className(),
            'AuditTrail' => [
                'class' => AuditTrailBehavior::className(),
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('app', 'ID'),
            'status' => Yii::t('app', 'Status'),
            'created_at' => Yii::t('app', 'Created At'),
            'updated_at' => Yii::t('app', 'Updated At'),
            'created_by' => Yii::t('app', 'Created By'),
            'updated_by' => Yii::t('app', 'Updated By'),
            'reference_number' => Yii::t('app', 'Reference Number'),
            'total_price' => Yii::t('app', 'Total Price'),
            'shipping_price' => Yii::t('app', 'Shipping Price'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getOrderItems()
    {
        return $this->hasMany(OrderItem::className(), ['parent_id' => 'id']);
    }

    public function getFullName()
    {
        return $this->first_name . ' ' . $this->last_name;
    }

    public static function calculateFees($amount)
    {
        return ($amount * 0.025) + 0.17;
    }

    public function sendSuccessEmail()
    {
        try {
            $output = DetailView::widget([
                'model' => $this,
                'attributes' => [
//                    'id',
                    'reference_number',
                    [
                        'attribute' => 'status',
                        'format' => 'raw',
                        'value' => $this->status == 'Transaction Successful' ? '<span class="text-success">' . $this->status . '</span>' : '<span class="text-danger">' . $this->status . '</span>',
                    ],
                    'first_name',
                    'last_name',
                    'mobile',
                    'email:email',
//                    'city',
                    'address_line_1',
                    'address_line_2',
                    'created_at:datetime',
                    'updated_at:datetime',
//                    'created_by',
//                    'updated_by',
                    'total_price',
                    'fees',
                    'shipping_price',
                ],
            ]);
            foreach ($this->orderItems as $item) {

                $output .= DetailView::widget([
                    'model' => $item,
                    'attributes' => [
                        'id',
                        'title',
                        'price',
                    ],
                ]);
            }
        } catch (\Exception $e) {
            return false;
        }


        $message = Yii::$app->mailer->compose()
            ->setTo($this->email)
            ->setFrom([Yii::$app->params['fromEmail'] => Yii::$app->params['fromName']])
            ->setSubject('New Order - Success')
            ->setHtmlBody($output)
            ->setTextBody('--');

//        return $message->send();
    }

    public function sendFailedEmail()
    {
        try {
            $output = DetailView::widget([
                'model' => $this,
                'attributes' => [
//                    'id',
                    'reference_number',
                    [
                        'attribute' => 'status',
                        'format' => 'raw',
                        'value' => $this->status == 'Transaction Successful' ? '<span class="text-success">' . $this->status . '</span>' : '<span class="text-danger">' . $this->status . '</span>',
                    ],
                    'first_name',
                    'last_name',
                    'mobile',
                    'email:email',
//                    'city',
                    'address_line_1',
                    'address_line_2',
                    'created_at:datetime',
                    'updated_at:datetime',
//                    'created_by',
//                    'updated_by',
                    'total_price',
                    'fees',
                    'shipping_price',
                ],
            ]);
            foreach ($this->orderItems as $item) {

                $output += DetailView::widget([
                    'model' => $item,
                    'attributes' => [
                        'id',
                        'title',
                        'price',
                    ],
                ]);
            }
        } catch (\Exception $e) {
            return false;
        }


        $message = Yii::$app->mailer->compose()
            ->setTo($this->email)
            ->setFrom([Yii::$app->params['fromEmail'] => Yii::$app->params['fromName']])
            ->setSubject('New Order - Failed')
            ->setHtmlBody($output)
            ->setTextBody('--');

//        return $message->send();
    }
}
