<?php

namespace backend\modules\places\models\search;

use common\components\SolrSearch;
use common\helpers\SolrDataProvider;
use Solarium\QueryType\Select\Query\Query;
use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\modules\places\models\Places;

/**
 * PlacesModelSearch represents the model behind the search form about `backend\modules\places\models\Places`.
 */
class PlacesModelSearch extends Places
{
    public $subsector_id;
    public $wheelchair_accessible_avg_f;
    public $quality_of_service_avg_f;
    public $spacious_interior_avg_f;
    public $lighting_brightness_avg_f;
    public $accessibility_is;
    public $group_is;

    public $sort_by = 'wheelchair_accessible_avg_f';

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id', 'kinz_id', 'city_id', 'district_id', 'sub_district_id', 'created_at', 'updated_at', 'created_by', 'updated_by', 'subsector_id', 'wheelchair_accessible_avg_f', 'spacious_interior_avg_f', 'quality_of_service_avg_f', 'lighting_brightness_avg_f'], 'integer'],
            [['phone', 'website', 'accessibility_is', 'group_is'], 'safe'],
            [['latitude', 'longitude'], 'number'],
            [['title', 'sort_by'], 'string'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return SolrDataProvider
     */
    public function solrSearch($params)
    {

        $this->load($params);

        /* @var $solr SolrSearch */

        $solr = Yii::$app->solr;
        $client = $solr->client;

// get a select query instance
        $query = $client->createSelect();

        if ($this->wheelchair_accessible_avg_f) {
            $query->createFilterQuery('wheelchair_accessible_avg_f')->setQuery("wheelchair_accessible_avg_f:[{$this->wheelchair_accessible_avg_f} TO 5]");
        }
        if ($this->spacious_interior_avg_f) {
            $query->createFilterQuery('spacious_interior_avg_f')->setQuery("spacious_interior_avg_f:[{$this->spacious_interior_avg_f} TO 5]");
        }
        if ($this->lighting_brightness_avg_f) {
            $query->createFilterQuery('lighting_brightness_avg_f')->setQuery("lighting_brightness_avg_f:[{$this->lighting_brightness_avg_f} TO 5]");
        }
        if ($this->quality_of_service_avg_f) {
            $query->createFilterQuery('quality_of_service_avg_f')->setQuery("quality_of_service_avg_f:[{$this->quality_of_service_avg_f} TO 5]");
        }

        if ($this->city_id) {
            $query->createFilterQuery('city_id')->setQuery("city_i:{$this->city_id}");
        }
        if ($this->district_id) {
            $query->createFilterQuery('district_id')->setQuery("district_i:{$this->district_id}");
        }
        if ($this->sub_district_id) {
            $query->createFilterQuery('district_id')->setQuery("subdistrict_i:{$this->sub_district_id}");
        }

        if ($this->subsector_id) {
            $query->createFilterQuery('subsector_id')->setQuery("subsector_is:{$this->subsector_id}");
        }
        if (count($this->accessibility_is)) {
            $values = implode(' OR ', $this->accessibility_is);
            $query->createFilterQuery('accessibility_is')->setQuery("accessibility_is:({$values})");
        }

        if ($this->group_is) {
            foreach ($this->group_is as $key => $group_i) {
                $values = implode(' OR ', $group_i);
                $query->createFilterQuery("group_{$key}_is")->setQuery("group_{$key}_is:({$values})");
            }
//            var_dump($query->getFilterQueries());
        }


        if ($this->title) {
            if(Yii::$app->language == 'ar') {
                $str = implode(' AND ', explode(' ', trim($this->title)));
                $query->setQuery("name_ar:({$str})");
            }else{
                $str = implode(' AND ', explode(' ', trim($this->title)));
                $query->setQuery("name:({$str})");
            }
        }

        if($this->sort_by) {
            $query->addSort($this->sort_by, Query::SORT_DESC);
        }
// this executes the query and returns the result
//        $resultset = $client->select($query);

// display the total number of documents found by solr
//        echo 'NumFound: ' . $resultset->getNumFound();


        $dataprovider = new SolrDataProvider([
            'solr' => $client,
            'query' => $query,
            'modelClass' => Places::className(),
            'pagination' => [
                'pageSize' => Yii::$app->settings->get('site.places_page_size', Yii::$app->settings->get('site.default_page_size')),
            ],
        ]);
        return ($dataprovider);


//        return $this->search($params);
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {


        /*
SELECT
	*
FROM
	places
	INNER JOIN place_subsector ON ( place_subsector.place_id = places.id )
	INNER JOIN place_filter ON ( place_filter.place_id = places.id )
	INNER JOIN place_aggregate_rating ON ( place_aggregate_rating.model_id = places.id )
	INNER JOIN place_accessibility on (place_accessibility.place_id = places.id)
WHERE
	city_id = 5
	AND place_subsector.subsector_id = 1 #Financial

	AND ( place_filter.filter_id IN ( 1503, 1502 ) ) #Commercial Banks & Islamic Banks
	and (place_aggregate_rating.wheelchair_accessible_avg >= 2 and place_aggregate_rating.quality_of_service_avg >= 4)
	and place_accessibility.accessibility_id in (17, 18)


        */


        $query = Places::find()->joinWith('translations');

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => Yii::$app->settings->get('site.places_page_size', Yii::$app->settings->get('site.default_page_size')),
            ],
            'sort' => [
                'defaultOrder' => [
                    'id' => SORT_DESC,
                ],
            ],
        ]);

        $this->load($params);

//        if (!$this->validate()) {
        // uncomment the following line if you do not want to return any records when validation fails
        // $query->where('0=1');
//            return $dataProvider;
//        }

        $query->andFilterWhere([
            'id' => $this->id,
            'kinz_id' => $this->kinz_id,
            'city_id' => $this->city_id,
            'latitude' => $this->latitude,
            'longitude' => $this->longitude,
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
            'created_by' => $this->created_by,
            'updated_by' => $this->updated_by,
        ]);

        $query->andFilterWhere(['like', 'phone', $this->phone])
            ->andFilterWhere(['like', 'website', $this->website]);

        $query->andFilterWhere(['like', 'title', $this->title]);


        if ($this->subsector_id) {
            $query->innerJoinWith('subsectors')
                ->andWhere(['subsector_id' => $this->subsector_id]);
        }


        //avoid translation duplicate
        $query->groupBy(['id']);

//        var_dump($query->createCommand()->rawSql);

        return $dataProvider;
    }
}
