<?php

use backend\modules\places\models\Filter;
use backend\modules\places\models\Group;
use backend\modules\places\models\Subsector;
use dosamigos\fileupload\FileUploadUI;
use dosamigos\google\maps\Event;
use dosamigos\google\maps\LatLng;
use dosamigos\google\maps\Map;
use dosamigos\google\maps\overlays\InfoWindow;
use dosamigos\google\maps\overlays\Marker;
//use kartik\builder\Form;
use kartik\builder\Form;
use kartik\depdrop\DepDrop;
use wbraganca\dynamicform\DynamicFormWidget;
use backend\modules\places\models\Places;
use yeesoft\helpers\Html;
use yeesoft\widgets\ActiveForm;
//use kartik\widgets\ActiveForm;
use yii\helpers\ArrayHelper;
use yii\helpers\Url;

/* @var $this yii\web\View */
/* @var $model backend\modules\places\models\Places */
/* @var $form yeesoft\widgets\ActiveForm */

$lng = Yii::$app->language;


?>

    <div class="places-form">

        <?php
        $form = ActiveForm::begin([
            'id' => 'places-form',
            'validateOnBlur' => false,
        ])
        ?>

        <div class="row">
            <div class="col-md-8">

                <div class="panel panel-default">
                    <div class="panel-body">


                        <?php if ($model->isMultilingual()): ?>
                            <?= \yeesoft\widgets\LanguagePills::widget() ?>
                        <?php endif; ?>

                        <?= $form->field($model, 'title')->textInput(['maxlength' => true]) ?>
                        <?= $form->field($model, 'slug')->textInput(['maxlength' => true]) ?>
                        <?= $form->field($model, 'description')->widget(\yeesoft\media\widgets\TinyMce::className(), [
                            'clientOptions' => [
                                'height' => 400,
                                'image_dimensions' => true,
                                'entity_encoding' => 'raw',
                                'plugins' => [
                                    'directionality code print preview fullpage searchreplace autolink directionality visualblocks visualchars fullscreen image link media template codesample table charmap hr pagebreak nonbreaking anchor toc insertdatetime advlist lists textcolor wordcount imagetools   contextmenu colorpicker textpattern',
                                ],
                                'toolbar' => 'undo redo | styleselect fontsizeselect bold italic | ltr rtl | alignleft aligncenter alignright alignjustify bullist numlist outdent indent | pagebreak link image table | forecolor backcolor | removeformat | code',

                            ]
                        ]); ?>

                        <?= $form->field($model, 'city_id')->widget(
                            \kartik\widgets\Select2::className(),
                            [

                                'options' => ['placeholder' => ''],
                                'pluginOptions' => ['allowClear' => true],
                                'data' => \yii\helpers\ArrayHelper::map(\backend\modules\city\models\City::find()->where(['status' => 1])->all(), 'id', 'title')

                            ]
                        ) ?>

                        <?= $form->field($model, 'phone')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'website')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'latitude')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'longitude')->textInput(['maxlength' => true]) ?>


                    </div>

                </div>
                <div>
                    <div class="panel panel-default">
                        <div class="panel-heading"><?php echo Yii::t('site', 'Map Location') ?></div>
                        <div class="panel-body">
                            <?php
                            $coord = new LatLng(['lat' => $model->latitude ?: 31.9454, 'lng' => $model->longitude ?: 35.9284]);
                            $map = new Map([
                                'center' => $coord,
                                'zoom' => 14,
                            ]);
                            $map->width = '100%';
                            // Lets add a marker now
                            $marker = new Marker([
                                'position' => $coord,
                                'title' => 'Drag me to change my location',
                            ]);
                            $marker->draggable = true;
                            // Provide a shared InfoWindow to the marker
                            $marker->attachInfoWindow(
                                new InfoWindow([
                                    'content' => '<p>Drag me to change my location</p>'
                                ])
                            );

                            $event = new Event([
                                "trigger" => "drag",
                                "js" => "document.getElementById('places-latitude').value = event.latLng.lat();document.getElementById('places-longitude').value = event.latLng.lng();"
                            ]);


                            $marker->addEvent($event);

                            // Add marker to the map
                            $map->addOverlay($marker);

                            // Display the map -finally :)
                            echo $map->display();
                            ?>


                        </div>
                    </div>
                </div>

            </div>

            <div class="col-md-4">

                <div class="panel panel-default">
                    <div class="panel-body">
                        <div class="record-info">
                            <div class="form-group clearfix">
                                <label class="control-label"
                                       style="float: left; padding-right: 5px;"><?= $model->attributeLabels()['id'] ?>
                                    : </label>
                                <span><?= $model->id ?></span>
                            </div>
                            <?php if (!$model->isNewRecord): ?>

                                <div class="form-group clearfix">
                                    <label class="control-label" style="float: left; padding-right: 5px;">
                                        <?= 'Slug' ?> :
                                    </label>
                                    <span><?= $model->slug ?></span>
                                </div>

                                <div class="form-group clearfix">
                                    <label class="control-label" style="float: left; padding-right: 5px;">
                                        <?= $model->attributeLabels()['created_at'] ?> :
                                    </label>
                                    <span><?= $model->createdDatetime ?></span>
                                </div>

                                <div class="form-group clearfix">
                                    <label class="control-label" style="float: left; padding-right: 5px;">
                                        <?= $model->attributeLabels()['updated_at'] ?> :
                                    </label>
                                    <span><?= $model->updatedDatetime ?></span>
                                </div>

                                <div class="form-group clearfix">
                                    <label class="control-label" style="float: left; padding-right: 5px;">
                                        <?= $model->attributeLabels()['updated_by'] ?> :
                                    </label>
                                    <span><?= $model->updatedBy ? $model->updatedBy->username : null ?></span>
                                </div>

                            <?php endif; ?>
                            <div class="form-group">
                                <?php if ($model->isNewRecord): ?>
                                    <?= Html::submitButton(Yii::t('yee', 'Create'), ['class' => 'btn btn-primary']) ?>
                                    <?= Html::a(Yii::t('yee', 'Cancel'), ['/places/default/index'], ['class' => 'btn btn-default']) ?>
                                <?php else: ?>
                                    <?= Html::submitButton(Yii::t('yee', 'Save'), ['class' => 'btn btn-primary']) ?>
                                    <?= Html::a(Yii::t('yee', 'Delete'),
                                        ['/places/default/delete', 'id' => $model->id], [
                                            'class' => 'btn btn-default',
                                            'data' => [
                                                'confirm' => Yii::t('yii', 'Are you sure you want to delete this item?'),
                                                'method' => 'post',
                                            ],
                                        ]) ?>
                                <?php endif; ?>
                            </div>
                            <div class="panel panel-default">
                                <div class="panel-body">

                                    <div class="record-info">

                                        <?= $form->field($model, 'status')->dropDownList(\yeesoft\page\models\Page::getStatusList()) ?>

                                        <?php if (!$model->isNewRecord): ?>
                                            <?= $form->field($model, 'created_by')->dropDownList(\common\models\User::getUsersList()) ?>
                                        <?php endif; ?>


                                    </div>
                                </div>
                            </div>
                            <div class="panel panel-default">
                                <div class="panel-heading"><?php echo Yii::t('site', 'Accessibility') ?></div>

                                <div class="panel-body">

                                    <div class="record-info">
                                        <?php try {
                                            echo $form->field($model, 'accessibilityValues')->label(false)->multiselect(
                                                \yii\helpers\ArrayHelper::map(\backend\modules\places\models\Accessibility::find()->joinWith('translations')->joinWith('subsectorAccessibilities')->where(['subsector_id' => ArrayHelper::map($model->subsectors, 'subsector_id', 'subsector_id')])->all(), 'id', 'title'),
                                                [
                                                    'height' => '225px',
                                                    'container' => ['class' => 'bg-white']
                                                ]
                                            );
                                        } catch (\yii\base\InvalidConfigException $e) {
                                            var_dump($e->getMessage());
                                        } ?>
                                    </div>
                                </div>
                            </div>

                            <div class="panel panel-default">
                                <div class="panel-body">
                                    <div class="record-info">
                                        <?= $form->field($model, 'thumbnail')->widget(yeesoft\media\widgets\FileInput::className(), [
                                            'name' => 'image',
                                            'buttonTag' => 'button',
                                            'buttonName' => Yii::t('yee', 'Browse'),
                                            'buttonOptions' => ['class' => 'btn btn-default btn-file-input'],
                                            'options' => ['class' => 'form-control'],
                                            'template' => '<div class="places-thumbnail thumbnail"></div><div class="input-group">{input}<span class="input-group-btn">{button}</span></div>',
                                            'thumb' => $this->context->module->thumbnailSize,
                                            'imageContainer' => '.places-thumbnail',
                                            'pasteData' => yeesoft\media\widgets\FileInput::DATA_URL,
                                            'callbackBeforeInsert' => 'function(e, data) {
                                $(".places-thumbnail").show();
                            }',
                                        ]) ?>
                                    </div>
                                </div>
                            </div>
                            <div class="panel panel-default">
                                <div class="panel-heading"><?php echo Yii::t('site', 'Images') ?></div>

                                <div class="panel-body">

                                    <div class="record-info">

                                        <?php try {
                                            $fileModel = new yeesoft\media\models\Media();
                                            echo
                                            FileUploadUI::widget([
                                                'model' => $fileModel,
                                                'attribute' => 'file',
                                                'url' => ['/media/manage/upload'],
                                                'gallery' => true,
                                                'fieldOptions' => [
                                                    'accept' => 'image/*'
                                                ],
                                                'clientOptions' => [
                                                    'maxFileSize' => 2000000
                                                ],
                                                // ...
                                                'clientEvents' => [
                                                    'fileuploaddone' => 'function(e, data) {
                                                    var result = data.result;
                                                    var file = result.files[0];
                                                    console.log(file.url);
                                                    $(\'<input>\').attr({
                                                        value: file.url,
                                                        type: \'hidden\',
                                                        name: \'Places[images][]\'
                                                    }).appendTo(\'form\');
                
                                                          
                                                }',
                                                    'fileuploadfail' => 'function(e, data) {
                
                                                }',
                                                ],
                                            ]);
                                        } catch (Exception $e) {
                                        }
                                        ?>

                                    </div>
                                </div>
                            </div>

                        </div>
                    </div>
                </div>

            </div>
        </div>


        <?php DynamicFormWidget::begin([
            'widgetContainer' => 'dynamicform_wrapper_c', // required: only alphanumeric characters plus "_" [A-Za-z0-9_]
            'widgetBody' => '.container-items_c', // required: css class selector
            'widgetItem' => '.item_c', // required: css class
            'limit' => 100, // the maximum times, an element can be cloned (default 999)
            'min' => 0, // 0 or 1 (default 1)
            'insertButton' => '.add-item_c', // css class
            'deleteButton' => '.remove-item_c', // css class
            'model' => $model->classifications[0],
            'formId' => 'places-form',
            'formFields' => [
                '[]subsector',
                '[]group',
                '[]filter'
            ],
        ]); ?>

        <div class="row">
            <div class="col-md-12">

                <div class="panel panel-default">
                    <div class="panel-heading">
                        <h3 class="panel-title"><?= Yii::t('app', 'Classification(s)') ?></h3>


                    </div>
                    <div class="pull-right panel-body">
                        <button type="button" class="add-item_c btn btn-success btn-sm">
                            <i class="glyphicon glyphicon-plus"></i> <?= yii::t('app', 'Add') ?>
                        </button>
                    </div>
                    <div class="clearfix"></div>
                    <div class="container-items_c"><!-- widgetContainer -->
                        <div class="item_c">
                            <div class="panel-body">
                                <div class="row">
                                    <div class="col-md-11">
                                        <?php

                                        try {
                                            $c = 0;
                                            echo Form::widget([
                                                'model' => new \backend\modules\places\models\ClassificationForm(),
                                                'form' => $form,
                                                'columns' => 3,
                                                'attributes' => [
                                                    "[$c]subsector" => [
                                                        'type' => Form::INPUT_WIDGET,
                                                        'label' => Yii::t('app', 'Level 1'),
                                                        'options' => [
                                                            'options' => ['placeholder' => Yii::t('app', 'Select ...')],
                                                            'pluginOptions' => ['allowClear' => true],
                                                            'data' => yii\helpers\ArrayHelper::map(SubSector::find()->addSelect(['id', "name_{$lng}"])->asArray()->all(), 'id', "name_{$lng}"),
                                                        ],
                                                        'widgetClass' => '\kartik\widgets\Select2'
                                                    ],
                                                    "[$c]group" => [
                                                        'type' => Form::INPUT_WIDGET,
                                                        'label' => Yii::t('app', 'Level 2'),
                                                        'options' => [
                                                            'type' => DepDrop::TYPE_SELECT2,
                                                            'options' => ['placeholder' => Yii::t('app', 'Select ...')],
                                                            'data' => ArrayHelper::map(Group::find()->orderBy("name_$lng")->asArray()->all(), 'id', "name_$lng"),
                                                            'select2Options' => ['pluginOptions' => ['allowClear' => true]],
                                                            'pluginOptions' => [
                                                                'placeholder' => Yii::t('app', 'Select ...'),
                                                                'depends' => ["classificationform-0-subsector"],
                                                                'url' => Url::to(['/places/default/dep-group']),

                                                            ],
                                                        ],
                                                        'widgetClass' => '\kartik\depdrop\DepDrop'
                                                    ],
                                                    "[$c]filter" => [
                                                        'type' => Form::INPUT_WIDGET,
                                                        'label' => Yii::t('app', 'Level 2'),
                                                        'options' => [
                                                            'type' => DepDrop::TYPE_SELECT2,
                                                            'options' => ['placeholder' => Yii::t('app', 'Select ...')],
                                                            'data' => ArrayHelper::map(Filter::find()->orderBy("name_$lng")->asArray()->all(), 'id', "name_$lng"),
                                                            'select2Options' => ['pluginOptions' => ['allowClear' => true]],
                                                            'pluginOptions' => [
                                                                'placeholder' => Yii::t('app', 'Select ...'),
                                                                'depends' => ["classificationform-0-group"],
                                                                'url' => Url::to(['/places/default/dep-filter']),

                                                            ],
                                                        ],
                                                        'widgetClass' => '\kartik\depdrop\DepDrop'
                                                    ],
                                                ]
                                            ]);
                                        } catch (Exception $e) {
                                            var_dump($e->getMessage());
                                        }
                                        ?>
                                    </div>
                                    <div class="col-md-1">
                                        <div style="text-align: right; margin-top: 31px">
                                            <button type="button" class="remove-item_c btn btn-danger btn-xs">
                                                <i class="glyphicon glyphicon-minus"></i></button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="clearfix"></div>
                    <?php $c = 101;
                    foreach ($model->classifications as $classificationModel): ?>
                        <div class="filter_item_c" pk="<?= $classificationModel->filter ?>">
                            <div class="panel-body">
                                <div class="row">
                                    <div class="col-md-11">
                                        <?php
                                        try {
                                            echo Form::widget([
                                                'model' => $classificationModel,
                                                'form' => $form,
                                                'columns' => 3,
                                                'attributes' => [
                                                    "[$c]subsector" => [
                                                        'type' => Form::INPUT_WIDGET,
                                                        'label' => Yii::t('app', 'Level 1'),
                                                        'options' => [
                                                            'options' => ['placeholder' => Yii::t('app', 'Select ...')],
                                                            'pluginOptions' => ['allowClear' => true],
                                                            'data' => yii\helpers\ArrayHelper::map(SubSector::find()->addSelect(['id', "name_{$lng}"])->asArray()->all(), 'id', "name_{$lng}"),
                                                        ],
                                                        'widgetClass' => '\kartik\widgets\Select2'
                                                    ],
                                                    "[$c]group" => [
                                                        'type' => Form::INPUT_WIDGET,
                                                        'label' => Yii::t('app', 'Level 2'),
                                                        'options' => [
                                                            'type' => DepDrop::TYPE_SELECT2,
                                                            'options' => ['placeholder' => Yii::t('app', 'Select ...')],
                                                            'data' => ArrayHelper::map(Group::find()->orderBy("name_$lng")->asArray()->all(), 'id', "name_$lng"),
                                                            'select2Options' => ['pluginOptions' => ['allowClear' => true]],
                                                            'pluginOptions' => [
                                                                'placeholder' => Yii::t('app', 'Select ...'),
                                                                'depends' => ["classificationform-{$c}-subsector"],
                                                                'url' => Url::to(['/places/default/dep-group']),

                                                            ],
                                                        ],
                                                        'widgetClass' => '\kartik\depdrop\DepDrop'
                                                    ],
                                                    "[$c]filter" => [
                                                        'type' => Form::INPUT_WIDGET,
                                                        'label' => Yii::t('app', 'Level 2'),
                                                        'options' => [
                                                            'type' => DepDrop::TYPE_SELECT2,
                                                            'options' => ['placeholder' => Yii::t('app', 'Select ...')],
                                                            'data' => ArrayHelper::map(Filter::find()->orderBy("name_$lng")->asArray()->all(), 'id', "name_$lng"),
                                                            'select2Options' => ['pluginOptions' => ['allowClear' => true]],
                                                            'pluginOptions' => [
                                                                'placeholder' => Yii::t('app', 'Select ...'),
                                                                'depends' => ["classificationform-{$c}-group"],
                                                                'url' => Url::to(['/places/default/dep-filter']),

                                                            ],
                                                        ],
                                                        'widgetClass' => '\kartik\depdrop\DepDrop'
                                                    ],
                                                ]
                                            ]);
                                        } catch (Exception $e) {
                                            var_dump($e->getMessage());
                                        }
                                        ?>
                                    </div>
                                    <div class="col-md-1">
                                        <div style="text-align: right; margin-top: 31px">
                                            <button pk="<?= $classificationModel->filter ?>"
                                                    pk_subsector="<?= $classificationModel->subsector ?>"
                                                    class="remove-filter_item_c btn btn-danger btn-xs">
                                                <i class="glyphicon glyphicon-minus"></i></button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php $c++; endforeach; ?>
                </div>
            </div>
        </div>
        <?php DynamicFormWidget::end(); ?>

        <?php ActiveForm::end(); ?>

    </div>


<?php
$js = <<<JS
    var thumbnail = $("#places-thumbnail").val();
    if(thumbnail.length == 0){
        $('.places-thumbnail').hide();
    } else {
        $('.places-thumbnail').html('<img src="' + thumbnail + '" />');
    }
JS;

$this->registerJs($js, yii\web\View::POS_READY);
?>