<?php

use yeesoft\helpers\Html;
use yeesoft\media\widgets\TinyMce;
use yeesoft\models\User;
use yeesoft\widgets\ActiveForm;
use yeesoft\widgets\LanguagePills;
use yii\jui\DatePicker;
use backend\modules\product\models\Product;

/* @var $this yii\web\View */
/* @var $model \backend\modules\product\models\Product */
/* @var $form yeesoft\widgets\ActiveForm */
?>

    <div class="page-form">

        <?php
        $form = ActiveForm::begin([
            'id' => 'product-form',
            'validateOnBlur' => false,
        ])
        ?>

        <div class="row">
            <div class="col-md-9">

                <div class="panel panel-default">
                    <div class="panel-body">

                        <?php if ($model->isMultilingual()): ?>
                            <?= LanguagePills::widget() ?>
                        <?php endif; ?>

                        <?= $form->field($model, 'title')->textInput(['maxlength' => true]) ?>
                        <?= $form->field($model, 'sub_title')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'brief')->textInput(['maxlength' => true]) ?>

                        <?php $form->field($model, 'slug')->textInput(['maxlength' => true]) ?>

                        <?php $form->field($model, 'content')->widget(TinyMce::className(),[
                            'clientOptions' => [
                                'height' => 400,
                                'image_dimensions' => true,
                                'entity_encoding' => 'raw',
                                'plugins' => [
                                    'directionality code print preview fullpage searchreplace autolink directionality visualblocks visualchars fullscreen image link media template codesample table charmap hr pagebreak nonbreaking anchor toc insertdatetime advlist lists textcolor wordcount imagetools   contextmenu colorpicker textpattern',
                                ],
                                'toolbar' => 'undo redo | styleselect fontsizeselect bold italic | ltr rtl | alignleft aligncenter alignright alignjustify bullist numlist outdent indent | pagebreak link image table | forecolor backcolor | removeformat | code',

                            ]
                        ]); ?>



                    </div>
                </div>
            </div>

            <div class="col-md-3">

                <div class="panel panel-default">
                    <div class="panel-body">
                        <div class="record-info">
                            <?php if (!$model->isNewRecord): ?>

                                <div class="form-group clearfix">
                                    <label class="control-label" style="float: left; padding-right: 5px;">
                                        <?= $model->attributeLabels()['created_at'] ?> :
                                    </label>
                                    <span><?= $model->createdDatetime ?></span>
                                </div>

                                <div class="form-group clearfix">
                                    <label class="control-label" style="float: left; padding-right: 5px;">
                                        <?= $model->attributeLabels()['updated_at'] ?> :
                                    </label>
                                    <span><?= $model->updatedDatetime ?></span>
                                </div>

                                <div class="form-group clearfix">
                                    <label class="control-label" style="float: left; padding-right: 5px;">
                                        <?= $model->attributeLabels()['updated_by'] ?> :
                                    </label>
                                    <span><?= $model->updatedBy->username ?></span>
                                </div>

                            <?php endif; ?>

                            <div class="form-group">
                                <?php if ($model->isNewRecord): ?>
                                    <?= Html::submitButton(Yii::t('yee', 'Create'), ['class' => 'btn btn-primary']) ?>
                                    <?= Html::a(Yii::t('yee', 'Cancel'), ['/product/default/index'], ['class' => 'btn btn-default',]) ?>
                                <?php else: ?>
                                    <?= Html::submitButton(Yii::t('yee', 'Save'), ['class' => 'btn btn-primary']) ?>
                                    <?=
                                    Html::a(Yii::t('yee', 'Delete'), ['/product/default/delete', 'id' => $model->id], [
                                        'class' => 'btn btn-default',
                                        'data' => [
                                            'confirm' => Yii::t('yii', 'Are you sure you want to delete this item?'),
                                            'method' => 'post',
                                        ],
                                    ])
                                    ?>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="panel panel-default">
                    <div class="panel-body">

                        <div class="record-info">
                            <?php
                            $form->field($model, 'is_online')->checkbox();
                            ?>

                            <?php
                                $form->field($model, 'url')->textInput(['maxlength' => true]) ?>

                            <?php
                            $form->field($model, 'type')->dropDownList(Product::getTypeList());
                            ?>
                            <?=
                            $form->field($model, 'on_homepage_main_slider')->checkbox();
                            ?>
                            <?php
                            $form->field($model, 'on_homepage_second_slider')->checkbox();
                            ?>
                            <?php
                            $form->field($model, 'color')->dropDownList(Product::getColorList());
                            ?>


                            <?php
                            $form->field($model, 'published_at')
                                ->widget(DatePicker::className(), ['dateFormat' => 'yyyy-MM-dd', 'options' => ['class' => 'form-control']]);
                            ?>

                            <?= $form->field($model, 'status')->dropDownList(Product::getStatusList()) ?>

                            <?php if (!$model->isNewRecord): ?>
                                <?= $form->field($model, 'created_by')->dropDownList(User::getUsersList()) ?>
                            <?php endif; ?>

                            <?php $form->field($model, 'view')->dropDownList($this->context->module->viewList) ?>

                            <?php $form->field($model, 'layout')->dropDownList($this->context->module->layoutList) ?>

                        </div>
                    </div>
                </div>


                <div class="panel panel-default">
                    <div class="panel-body">

                        <div class="record-info">

                            <?= $form->field($model, 'image')->widget(yeesoft\media\widgets\FileInput::className(), [
                                'name' => 'image',
                                'buttonTag' => 'button',
                                'buttonName' => Yii::t('yee', 'Browse'),
                                'buttonOptions' => ['class' => 'btn btn-default btn-file-input'],
                                'options' => ['class' => 'form-control'],
                                'template' => '<div class="post-image thumbnail"></div><div class="input-group">{input}<span class="input-group-btn">{button}</span></div>',
                                'thumb' => $this->context->module->thumbnailSize,
                                'imageContainer' => '.post-image',
                                'pasteData' => yeesoft\media\widgets\FileInput::DATA_URL,
                                'callbackBeforeInsert' => 'function(e, data) {
                                $(".post-image").show();
                            }',
                            ]) ?>
                            <?= $form->field($model, 'image_header')->widget(yeesoft\media\widgets\FileInput::className(), [
                                'name' => 'image_header',
                                'buttonTag' => 'button',
                                'buttonName' => Yii::t('yee', 'Browse'),
                                'buttonOptions' => ['class' => 'btn btn-default btn-file-input'],
                                'options' => ['class' => 'form-control'],
                                'template' => '<div class="post-image_header thumbnail"></div><div class="input-group">{input}<span class="input-group-btn">{button}</span></div>',
                                'thumb' => $this->context->module->thumbnailSize,
                                'imageContainer' => '.post-image_header',
                                'pasteData' => yeesoft\media\widgets\FileInput::DATA_URL,
                                'callbackBeforeInsert' => 'function(e, data) {
                                $(".post-image_header").show();
                            }',
                            ]) ?>

                            <?php $form->field($model, 'icon_1')->widget(yeesoft\media\widgets\FileInput::className(), [
                                'name' => 'image',
                                'buttonTag' => 'button',
                                'buttonName' => Yii::t('yee', 'Browse'),
                                'buttonOptions' => ['class' => 'btn btn-default btn-file-input'],
                                'options' => ['class' => 'form-control'],
                                'template' => '<div class="post-icon-1 thumbnail"></div><div class="input-group">{input}<span class="input-group-btn">{button}</span></div>',
                                'thumb' => $this->context->module->thumbnailSize,
                                'imageContainer' => '.post-icon-1',
                                'pasteData' => yeesoft\media\widgets\FileInput::DATA_URL,
                                'callbackBeforeInsert' => 'function(e, data) {
                                $(".post-icon-1").show();
                            }',
                            ]) ?>

                            <?php $form->field($model, 'icon_2')->widget(yeesoft\media\widgets\FileInput::className(), [
                                'name' => 'image',
                                'buttonTag' => 'button',
                                'buttonName' => Yii::t('yee', 'Browse'),
                                'buttonOptions' => ['class' => 'btn btn-default btn-file-input'],
                                'options' => ['class' => 'form-control'],
                                'template' => '<div class="post-icon-2 thumbnail"></div><div class="input-group">{input}<span class="input-group-btn">{button}</span></div>',
                                'thumb' => $this->context->module->thumbnailSize,
                                'imageContainer' => '.post-icon-2',
                                'pasteData' => yeesoft\media\widgets\FileInput::DATA_URL,
                                'callbackBeforeInsert' => 'function(e, data) {
                                $(".post-icon-2").show();
                            }',
                            ]) ?>


                            <?php $form->field($model, 'icon_3')->widget(yeesoft\media\widgets\FileInput::className(), [
                                'name' => 'image',
                                'buttonTag' => 'button',
                                'buttonName' => Yii::t('yee', 'Browse'),
                                'buttonOptions' => ['class' => 'btn btn-default btn-file-input'],
                                'options' => ['class' => 'form-control'],
                                'template' => '<div class="post-icon-3 thumbnail"></div><div class="input-group">{input}<span class="input-group-btn">{button}</span></div>',
                                'thumb' => $this->context->module->thumbnailSize,
                                'imageContainer' => '.post-icon-3',
                                'pasteData' => yeesoft\media\widgets\FileInput::DATA_URL,
                                'callbackBeforeInsert' => 'function(e, data) {
                                $(".post-icon-3").show();
                            }',
                            ]) ?>

                        </div>
                    </div>
                </div>


            </div>
        </div>

        <?php ActiveForm::end(); ?>

    </div>


<?php


$js = <<<JS
    var image = $("#product-image").val();
    if(image.length == 0){
        $('.post-image').hide();
    } else {
        $('.post-image').html('<img src="' + image + '" />');
    }
     var image = $("#product-image_header").val();
    if(image.length == 0){
        $('.post-image_header').hide();
    } else {
        $('.post-image_header').html('<img src="' + image + '" />');
    }
    
    var image = $("#product-icon_1").val();
    if(image.length == 0){
        $('.post-icon-1').hide();
    } else {
        $('.post-icon-1').html('<img src="' + image + '" />');
    }
    
    
    var image = $("#product-icon_2").val();
    if(image.length == 0){
        $('.post-icon-2').hide();
    } else {
        $('.post-icon-2').html('<img src="' + image + '" />');
    }
    
    var image = $("#product-icon_3").val();
    if(image.length == 0){
        $('.post-icon-3').hide();
    } else {
        $('.post-icon-3').html('<img src="' + image + '" />');
    }
    

JS;

$this->registerJs($js, yii\web\View::POS_END);
?>