<?php

namespace backend\modules\quotes_request\forms;

use backend\modules\quotes_request\models\FirstHomePlusInsurance;
use common\helpers\Utility;
use Yii;
use yii\helpers\ArrayHelper;
use yii\web\UploadedFile;


class FirstHomePlusForm extends FirstHomePlusInsurance
{



    public function rules()
    {
        return [
            [[ 'year_of_loss', 'amount_of_insurance', 'location_appartment_number', 'location_floor_number', 'building_age', 'house_is_exposed_to_loss', 'created', 'updated'], 'integer'],
            [['reject_reason'], 'string'],
            [['insured_start_date'], 'safe'],
            [['initial_price', 'discount', 'final_price'], 'number'],
            [['reference_number', 'first_name', 'second_name', 'third_name', 'family_name', 'email', 'insured_city', 'insured_phone', 'insured_building', 'insured_reponsibility', 'insured_personal_accidents', 'insured_loss_of_rent', 'location_city', 'location_district', 'location_street', 'location_building_number', 'location_segment', 'segment_basin_number', 'owner_name', 'identity_file', 'registration_file', 'city', 'district', 'street', 'request_status', 'payment_method'], 'string', 'max' => 255],
            [['mobile_number', 'building_number'], 'string', 'max' => 50],

            [['first_name', 'second_name', 'third_name', 'family_name', 'email', 'mobile_number', 'amount_of_insurance'], 'required', 'on' => ['stage_one', 'admin']],
            [['insured_city', 'insured_phone', 'insured_building', 'insured_reponsibility', 'insured_personal_accidents', 'insured_loss_of_rent', 'location_appartment_number', 'location_floor_number', 'building_age', 'house_is_exposed_to_loss', 'insured_contains', 'insured_start_date', 'location_city', 'location_district', 'location_street', 'location_building_number', 'location_segment', 'segment_basin_number', 'owner_name', ], 'required', 'on' => ['stage_two', 'admin']],
            [['email'], 'email'],
            ['year_of_loss', 'required', 'when' => function ($model) {
                return $model->house_is_exposed_to_loss == 1;
            }, 'whenClient' => "function (attribute, value) {
                    return $('#firsthomeform-house_is_exposed_to_loss').val() == 1;
                }"
            ],
            [['identity_file', 'registration_file'], 'file', 'maxSize' => 1024 * 1024 * 50, 'extensions' => 'jpg, jpeg, png, bmp, pdf'],


        ];
    }


    public function setDefaults()
    {
        $this->reference_number = Utility::create_guid();
    }

    public function calculateQuote()
    {
        $price = 0;

        $percent = Yii::$app->settings->get('first_home_plus_insurance.percentage');
        $min_amount = Yii::$app->settings->get('first_home_plus_insurance.min_amount');


        $price = $this->amount_of_insurance * ($percent / 100);
        $price = max($price, $min_amount);


        $this->initial_price = $this->final_price = $price;

        $discount = Yii::$app->settings->get('first_home_plus_insurance.discount');

        if ($discount) {
            $this->discount = ($this->initial_price * $discount / 100);
            $this->final_price = ($this->initial_price - $this->discount);
        }

    }

    /**
     * @param bool $insert
     * @return bool
     */
    public function beforeSave($insert)
    {
        if ($insert) {
            $this->calculateQuote();
        }
        if($this->insured_contains){
            $this->insured_contains = serialize($this->insured_contains);

        }
        return parent::beforeSave($insert);
    }

    public static function GetContainsList()
    {
        return [
            'A', 'B', 'C', 'D', 'E', 'F', 'G'
        ];
    }

    public function uploadFiles()
    {
        $routes = [
            'baseUrl' => '', // Base absolute path to web directory
            'basePath' => '@frontend/web', // Base web directory url
            'uploadPath' => 'uploads/quote', // Path for uploaded files in web directory
        ];
        try {
            $file1 = UploadedFile::getInstance(new self(), "registration_file");
            $media1 = Utility::saveUploadedFile($file1, $routes);
            //$this->familyBookFile = $media1->file;
            $this->registration_file = $media1->url;
        } catch (\Exception $e) {
        }
        try {
            $file2 = UploadedFile::getInstance(new self(), "identity_file");
            $media2 = Utility::saveUploadedFile($file2, $routes);
            //$this->identityFile = $media2->file;
            $this->identity_file = $media2->url;
        } catch (\Exception $e) {
        }

    }

}
