<?php

namespace backend\modules\quotes_request\forms;

use backend\modules\quotes_criteria\models\CarBrand;
use backend\modules\quotes_request\models\IndividualMedicalInsurance;
use backend\modules\quotes_request\models\MotorInsurance;
use common\helpers\Utility;
use DateTime;
use Yii;
use yii\helpers\ArrayHelper;
use yii\web\UploadedFile;


class IndividualInsuranceForm extends IndividualMedicalInsurance
{

    public $family;


    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['date_of_birth'], 'safe'],
            [['reject_reason'], 'string'],
            [['created', 'updated'], 'integer'],
            [['initial_price', 'discount', 'final_price'], 'number'],
            [['reference_number', 'first_name', 'second_name', 'third_name', 'family_name', 'email', 'programe_type', 'class_type', 'home_phone', 'home_fax', 'work_city', 'work_district', 'work_street',  'social_status', 'proof of personality', 'home_city', 'request_status', 'payment_method'], 'string', 'max' => 255],
            [['work_building_number', 'mobile_number'], 'string', 'max' => 50],
            [['identity_file', 'family_book_file'], 'string', 'max' => 255],
            [['gender'], 'string', 'max' => 10],
            [['diseases_list'], 'each', 'rule' => ['string']],
            [['social_status', 'date_of_birth', 'gender', 'mobile_number', 'first_name', 'second_name', 'third_name', 'family_name', 'email', 'programe_type', 'class_type',], 'required', 'on' => 'stage_one'],
            [['diseases_list', 'family_book_file', 'identity_file', 'home_city', 'home_phone', 'home_fax', 'work_city', 'work_district', 'work_street', 'work_building_number'], 'required', 'on' => 'stage_two'],
            [['family_book_file', 'identity_file'], 'file', 'maxSize' => 1024 * 1024 * 50, 'extensions' => 'jpg, jpeg, png, bmp, pdf'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'reference_number' => Yii::t('site', 'Reference Number'),
            'first_name' => Yii::t('site', 'First Name'),
            'second_name' => Yii::t('site', 'Second Name'),
            'third_name' => Yii::t('site', 'Third Name'),
            'family_name' => Yii::t('site', 'Family Name'),
            'email' => Yii::t('site', 'Email'),
            'mobile_number' => Yii::t('site', 'Mobile Number'),
            'programe_type' => Yii::t('site', 'Programe Type'),
            'class_type' => Yii::t('site', 'Class Type'),
            'home_phone' => Yii::t('site', 'Home Phone'),
            'home_fax' => Yii::t('site', 'Home Fax'),
            'work_city' => Yii::t('site', 'Work City'),
            'work_district' => Yii::t('site', 'Work District'),
            'work_street' => Yii::t('site', 'Work Street'),
            'work_building_number' => Yii::t('site', 'Work Building Number'),
            'family_book_file' => Yii::t('site', 'Family Book File'),
            'identity_file' => Yii::t('site', 'Identity File'),
            'gender' => Yii::t('site', 'Gender'),
            'date_of_birth' => Yii::t('site', 'Date Of Birth'),
            'social_status' => Yii::t('site', 'Social Status'),
            'proof of personality' => Yii::t('site', 'Proof Of Personality'),
            'home_city' => Yii::t('site', 'Home City'),
            'diseases_list' => Yii::t('site', 'Diseases List'),
            'created' => Yii::t('site', 'Created'),
            'updated' => Yii::t('site', 'Updated'),
            'initial_price' => Yii::t('site', 'Initial Price'),
            'discount' => Yii::t('site', 'Discount'),
            'final_price' => Yii::t('site', 'Final Price'),
            'request_status' => Yii::t('site', 'Request Status'),
            'reject_reason' => Yii::t('site', 'Reject Reason'),
            'payment_method' => Yii::t('site', 'Payment Method'),
        ];
    }

    public function setDefaults()
    {
        $this->reference_number = Utility::create_guid();
    }


    public function calculateQuote()
    {
        $price = $additional_price = 0;
        // My Birthday
        $date_1 = new DateTime($this->date_of_birth);
        // Todays date
        $date_2 = new DateTime(date('Y-m-d'));
        $difference = $date_2->diff($date_1);

//inpatient_male_vip_20
        $plan = strtolower($this->programe_type) . '_' . strtolower($this->gender) . '_' . strtolower($this->class_type) . '_' . self::getYearRang($difference->y);

        $price = (float)Yii::$app->settings->get('individual_insurance.' . $plan);


        foreach ($this->individualMedicalInsuranceFamilyLists as $familyList) {
            $additional_price += $familyList->calculateQuote();
        }

        $this->initial_price = $this->final_price = ($price + $additional_price);

        $discount = Yii::$app->settings->get('individual.discount');

        if ($discount) {
            $this->discount = ($this->initial_price * $discount / 100);
            $this->final_price = ($this->initial_price - $this->discount);
        }
    }

    public static function getYearRang($year)
    {
        $year = $year ?: 1;//switch issue
        switch ($year) {
            case $year <= 20:
                $rang = '20';
                break;
            case $year <= 25:
                $rang = '25';
                break;
            case $year <= 30:
                $rang = '30';
                break;
            case $year <= 35:
                $rang = '35';
                break;
            case $year <= 40:
                $rang = '40';
                break;
            case $year <= 45:
                $rang = '45';
                break;
            case $year <= 50:
                $rang = '50';
                break;
            case $year <= 55:
                $rang = '55';
                break;
            case $year <= 60:
                $rang = '60';
                break;
            case $year <= 65:
                $rang = '65';
                break;
            case $year <= 70:
                $rang = '70';
                break;
            case $year <= 75:
                $rang = '75';
                break;
            case $year <= 99:
                $rang = '99';
                break;
        }
        return $rang;
    }

    /**
     * @param bool $insert
     * @return bool
     */
    public function beforeSave($insert)
    {
        if ($insert) {
            $this->calculateQuote();
        }
        return parent::beforeSave($insert);
    }


    public static function getProgramTypeList()
    {
        return [
            'inpatient' => Yii::t('site', 'In Patient'),
            'inoutpatient/' => Yii::t('site', 'In/Out Patient')];
    }

    public static function getClassTypeList()
    {
        return [
            'VIP' => Yii::t('site', 'Vip'),
            'A' => Yii::t('site', 'A'),
            'B' => Yii::t('site', 'B'),
            'C' => Yii::t('site', 'C'),
        ];
    }

    public static function getDiseaseList()
    {
        return
            [
                [
                    'key' => 'Heart and Blood Vessels',
                    'value' => Yii::t('site', 'Heart and Blood Vessels')
                ],
                [
                    'key' => 'Congenital and genetic conditions',
                    'value' => Yii::t('site', 'Congenital and genetic conditions')
                ],
                [
                    'key' => 'cancer',
                    'value' => Yii::t('site', 'Cancer')
                ],
                [
                    'key' => 'Mental, psychological and neurological diseases',
                    'value' => Yii::t('site', 'Mental, psychological and neurological diseases')
                ],
                [
                    'key' => 'Kidney disease',
                    'value' => Yii::t('site', 'Kidney disease')
                ],
                [
                    'key' => 'Gastroenterology',
                    'value' => Yii::t('site', 'Gastroenterology')
                ],
                [
                    'key' => 'Respiratory system diseases',
                    'value' => Yii::t('site', 'Respiratory system diseases')
                ],
                [
                    'key' => 'AIDS',
                    'value' => Yii::t('site', 'AIDS')
                ],
                [
                    'key' => 'Diseases of bones, muscles and joints',
                    'value' => Yii::t('site', 'Diseases of bones, muscles and joints')
                ],
                [
                    'key' => 'Urinary and genital diseases',
                    'value' => Yii::t('site', 'Urinary and genital diseases')
                ],
                [
                    'key' => 'Diseases of the lymphatic system',
                    'value' => Yii::t('site', 'Diseases of the lymphatic system')
                ],
                [
                    'key' => 'Pregnancy, childbirth and complications',
                    'value' => Yii::t('site', 'Pregnancy, childbirth and complications')
                ],
                [
                    'key' => 'Endocrine diseases and diabetes',
                    'value' => Yii::t('site', 'Endocrine diseases and diabetes')
                ],
                [
                    'key' => 'Arthritis and immune diseases',
                    'value' => Yii::t('site', 'Arthritis and immune diseases')
                ],
                [
                    'key' => 'Any previous surgical procedures',
                    'value' => Yii::t('site', 'Any previous surgical procedures')
                ],
                [
                    'key' => 'Back pain and spine',
                    'value' => Yii::t('site', 'Back pain and spine')
                ],
                [
                    'key' => 'Hypertension',
                    'value' => Yii::t('site', 'Hypertension')
                ],
                [
                    'key' => 'skin diseases',
                    'value' => Yii::t('site', 'skin diseases')
                ],
                [
                    'key' => 'Any illness or complaint is not mentioned',
                    'value' => Yii::t('site', 'Any illness or complaint is not mentioned')
                ],

            ];
    }

    public function saveDiseasesList()
    {
//        var_dump($this->diseases_list);die();
        $this->diseases_list = serialize($this->diseases_list);

    }

    public function uploadFiles()
    {
        $routes = [
            'baseUrl' => '', // Base absolute path to web directory
            'basePath' => '@frontend/web', // Base web directory url
            'uploadPath' => 'uploads/quote', // Path for uploaded files in web directory
        ];
        try {
            $file1 = UploadedFile::getInstance(new self(), "family_book_file");
            $media1 = Utility::saveUploadedFile($file1, $routes);
            //$this->familyBookFile = $media1->file;
            $this->family_book_file = $media1->url;
        } catch (\Exception $e) {
        }
        try {
            $file2 = UploadedFile::getInstance(new self(), "identity_file");
            $media2 = Utility::saveUploadedFile($file2, $routes);
            //$this->identityFile = $media2->file;
            $this->identity_file = $media2->url;
        } catch (\Exception $e) {
        }

    }

}
