<?php

namespace backend\modules\quotes_request\forms;

use backend\modules\quotes_criteria\models\CarBrand;
use backend\modules\quotes_request\models\MotorInsurance;
use common\helpers\Utility;
use Yii;
use yii\helpers\ArrayHelper;
use yii\web\UploadedFile;


class MotorInsuranceForm extends MotorInsurance
{


    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['reference_number', 'first_name', 'second_name', 'third_name',
                'family_name', 'email', 'mobile_number', 'registration_status',
                'vehicle_type', 'car_model', 'manufacturing_year', 'amount_of_insurance',
                'fuel_type', 'repair_agency'], 'required', 'on' => ['stage_one', 'admin']],
            [['name_of_insured', 'via', 'city', 'district', 'street',
                'building_number', 'home_number', 'gender', 'date_of_birth', 'career',
                'plate_Number', 'vin_number', 'national_number', 'registration_number', 'driving_license_file', 'Identity_commercial_file', 'beneficiary_name'], 'required', 'on' => ['stage_two', 'admin']],
            [['manufacturing_year', 'date_of_birth'], 'safe'],
            [['amount_of_insurance', 'repair_agency', 'created', 'updated', 'vehicle_type', 'car_model'], 'integer'],
            [['initial_price', 'final_price'], 'number'],
            [['payment_method', 'reference_number', 'first_name', 'second_name', 'third_name', 'family_name', 'email', 'registration_status', 'fuel_type', 'name_of_insured', 'via', 'beneficiary_name', 'city', 'district', 'street', 'career', 'vin_number', 'engine_serial_number', 'national_number', 'registration_number', 'driving_license_file', 'Identity_commercial_file', 'request_status'], 'string', 'max' => 255],
            [['mobile_number', 'building_number', 'home_number', 'plate_Number'], 'string', 'max' => 50],
            [['gender'], 'string', 'max' => 10],
            [['email'], 'email'],
            //[['driving_license_file', 'Identity_commercial_file'], 'file', 'skipOnEmpty' => false, 'extensions' => 'jpg, jpeg, png, bmp, jpe'],
            ['manufacturing_year', 'validateYear'],
            ['amount_of_insurance', 'integer', 'min' => 1, 'max' => self::getMaxAmountOfInsurance()],
            [['driving_license_file', 'Identity_commercial_file'], 'file', 'maxSize' => 1024 * 1024 * 50, 'extensions' => 'jpg, jpeg, png, bmp, pdf'],

        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'reference_number' => Yii::t('site', 'Reference Nmber'),
            'first_name' => Yii::t('site', 'First Name'),
            'second_name' => Yii::t('site', 'Second Name'),
            'third_name' => Yii::t('site', 'Third Name'),
            'family_name' => Yii::t('site', 'Family Name'),
            'email' => Yii::t('site', 'Email'),
            'mobile_number' => Yii::t('site', 'Mobile Number'),
            'registration_status' => Yii::t('site', 'Registration Status'),
            'vehicle_type' => Yii::t('site', 'Vehicle Type'),
            'car_model' => Yii::t('site', 'Car Model'),
            'manufacturing_year' => Yii::t('site', 'Manufacturing Year'),
            'amount_of_insurance' => Yii::t('site', 'Amount Of Insurance'),
            'fuel_type' => Yii::t('site', 'Fuel Type'),
            'repair_agency' => Yii::t('site', 'Repair Agency'),
            'name_of_insured' => Yii::t('site', 'Name Of Insured'),
            'via' => Yii::t('site', 'Via'),
            'beneficiary_name' => Yii::t('site', 'Beneficiary Name'),
            'city' => Yii::t('site', 'City'),
            'district' => Yii::t('site', 'District'),
            'street' => Yii::t('site', 'Street'),
            'building_number' => Yii::t('site', 'Building Number'),
            'home_number' => Yii::t('site', 'Home Number'),
            'gender' => Yii::t('site', 'Gender'),
            'date_of_birth' => Yii::t('site', 'Date Of Birth'),
            'career' => Yii::t('site', 'Career'),
            'plate_Number' => Yii::t('site', 'Plate  Number'),
            'vin_number' => Yii::t('site', 'Vin Number'),
            'engine_serial_number' => Yii::t('site', 'Engine Serial Number'),
            'national_number' => Yii::t('site', 'National Number'),
            'registration_number' => Yii::t('site', 'Registration Number'),
            'driving_license_file' => Yii::t('site', 'Driving License File'),
            'Identity_commercial_file' => Yii::t('site', 'Identity Commercial File'),
            'created' => Yii::t('site', 'Created'),
            'updated' => Yii::t('site', 'Updated'),
            'initial_price' => Yii::t('site', 'Initial Price'),
            'final_price' => Yii::t('site', 'Final Price'),
            'request_status' => Yii::t('site', 'Request Status'),
            'payment_method' => Yii::t('site', 'Payment Method'),
        ];
    }

    public function setDefaults()
    {
        $this->reference_number = Utility::create_guid();
        $this->registration_status = 'Private - Salon only';
    }

    public static function getMaxAmountOfInsurance()
    {
        $maxAmount = Yii::$app->settings->get('motor.max_amount');
        return $maxAmount;
    }

    public static function getRegistrationStatusList()
    {
        return [
            'Private - Salon only' => Yii::t('quote', 'Private - Salon only')
        ];
    }

    public function validateYear($attribute, $params, $validator)
    {
        //if Agency Repair checked, 2 Year Max
        $maxYear = Yii::$app->settings->get('motor.agency_repair_max_year');
        $currentYear = date('Y');
        if ($this->repair_agency && ($currentYear - $this->$attribute > $maxYear)) {
            $this->addError($attribute, Yii::t('quote', "The Year must be minimum {MaxYear} year.", ['MaxYear' => $currentYear - $maxYear]));
        }

        $carBrand = CarBrand::findOne($this->vehicle_type);
        if ($carBrand && ($currentYear - $this->$attribute > $carBrand->max_car_age)) {
            $this->addError($attribute, Yii::t('quote', "The Year must be minimum {MinYear} year.", ['MinYear' => ($currentYear - $carBrand->max_car_age)]));

        }
    }


    public static function getVehicleTypeList()
    {
        return ArrayHelper::map(CarBrand::find()->all(), 'id', "title");
    }

    public static function getYearList()
    {
        $endY = date('Y');
        $startY = $endY - CarBrand::find()->max('max_car_age');


        return array_combine(range($startY, $endY), range($startY, $endY));

    }

    public static function getFuelTypeList()
    {
        return [
            'Electricity' => Yii::t('quote', 'Electricity'),
            'Hybrids' => Yii::t('quote', 'Hybrids'),
            'Gas' => Yii::t('quote', 'Gas')
        ];
    }

    public static function getPaymentMethodList()
    { return [
        'Cash' => Yii::t('quote', 'Cash'),
        'Paypal' => Yii::t('quote', 'Paypal')
    ];
    }

    public function calculateQuote()
    {
        $price = $additional_price = 0;

        $electricPercent = Yii::$app->settings->get('motor.electric_car_percentage');
        $electricMinAmount = Yii::$app->settings->get('motor.electric_car_min_amount');


        if ($this->fuel_type == 'Electricity') {
            $price = $this->amount_of_insurance * ($electricPercent / 100);
            $price = max($price, $electricMinAmount);
        } else {
            switch ($this->amount_of_insurance) {
                case ($this->amount_of_insurance <= Yii::$app->settings->get('motor.rang_one')):
                    $price = Yii::$app->settings->get('motor.rang_one_initial_amount');
                    break;
                case ($this->amount_of_insurance < Yii::$app->settings->get('motor.rang_two')):
                    $price = Yii::$app->settings->get('motor.rang_two_initial_amount') + (($this->amount_of_insurance - Yii::$app->settings->get('motor.rang_two_subtract_amount')) * Yii::$app->settings->get('motor.rang_two_percentage') / 100);
                    break;
                case ($this->amount_of_insurance < Yii::$app->settings->get('motor.rang_three')):
                    $price = Yii::$app->settings->get('motor.rang_three_initial_amount') + (($this->amount_of_insurance - Yii::$app->settings->get('motor.rang_three_subtract_amount')) * Yii::$app->settings->get('motor.rang_three_percentage') / 100);
                    break;
                case ($this->amount_of_insurance < Yii::$app->settings->get('motor.rang_four')):
                    $price = Yii::$app->settings->get('motor.rang_four_initial_amount') + (($this->amount_of_insurance - Yii::$app->settings->get('motor.rang_four_subtract_amount')) * Yii::$app->settings->get('motor.rang_four_percentage') / 100);
                    break;
            }
        }

        if ($this->repair_agency) {
            $percent = Yii::$app->settings->get('motor.agency_repair_percentage');
            $minimum = Yii::$app->settings->get('motor.agency_repair_min_amount');
            $additional_price = max($minimum, ($price * $percent / 100));
        }


        $this->initial_price = $this->final_price = ($price + $additional_price);

        $discount = Yii::$app->settings->get('motor.discount');

        if($discount){
            $this->discount = ($this->initial_price * $discount / 100);
            $this->final_price = ($this->initial_price - $this->discount);
        }

    }

    /**
     * @param bool $insert
     * @return bool
     */
    public function beforeSave($insert)
    {
        if($insert) {
            $this->calculateQuote();
        }
        return parent::beforeSave($insert);
    }

    public function uploadFiles()
    {
        $routes = [
            'baseUrl' => '', // Base absolute path to web directory
            'basePath' => '@frontend/web', // Base web directory url
            'uploadPath' => 'uploads/quote', // Path for uploaded files in web directory
        ];
        try {
            $file1 = UploadedFile::getInstance(new self(), "driving_license_file");
            $media1 = Utility::saveUploadedFile($file1, $routes);
            //$this->familyBookFile = $media1->file;
            $this->driving_license_file = $media1->url;
        } catch (\Exception $e) {
        }
        try {
            $file2 = UploadedFile::getInstance(new self(), "identity_file");
            $media2 = Utility::saveUploadedFile($file2, $routes);
            //$this->identityFile = $media2->file;
            $this->identity_file = $media2->url;
        } catch (\Exception $e) {
        }

    }
}
