<?php

namespace backend\modules\quotes_request\models;

use backend\modules\quotes_request\forms\IndividualInsuranceForm;
use bedezign\yii2\audit\AuditTrailBehavior;
use common\helpers\Utility;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\TimestampBehavior;
use yii\web\UploadedFile;

/**
 * This is the model class for table "individual_medical_insurance".
 *
 * @property int $id
 * @property string $reference_number
 * @property string $first_name
 * @property string $second_name
 * @property string $third_name
 * @property string $family_name
 * @property string $email
 * @property string $mobile_number
 * @property string $programe_type
 * @property string $class_type
 * @property string $home_phone
 * @property string $home_fax
 * @property string $work_city
 * @property string $work_district
 * @property string $work_street
 * @property string $work_building_number
 * @property string $family_book_file
 * @property string $identity_file
 * @property string $gender
 * @property string $date_of_birth
 * @property string $social_status
 * @property string $proof of personality
 * @property string $home_city
 * @property string $diseases_list
 * @property int $created
 * @property int $updated
 * @property string $initial_price
 * @property string $discount
 * @property string $final_price
 * @property string $request_status
 * @property string $reject_reason
 * @property string $payment_method
 *
 * @property IndividualMedicalInsuranceFamilyList[] $individualMedicalInsuranceFamilyLists
 */
class IndividualMedicalInsurance extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'individual_medical_insurance';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['date_of_birth'], 'safe'],
            [['diseases_list', 'reject_reason'], 'string'],
            [['created', 'updated'], 'integer'],
            [['initial_price', 'discount', 'final_price'], 'number'],
            [['reference_number', 'first_name', 'second_name', 'third_name', 'family_name', 'email', 'programe_type', 'class_type', 'home_phone', 'home_fax', 'work_city', 'work_district', 'work_street',  'social_status', 'proof of personality', 'home_city', 'request_status', 'payment_method'], 'string', 'max' => 255],
            [['mobile_number', 'work_building_number'], 'string', 'max' => 50],
            [['gender'], 'string', 'max' => 10],
        ];
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            AuditTrailBehavior::className(),
            'Timestamp' => [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'created',
                'updatedAtAttribute' => 'updated',
            ],
            BlameableBehavior::className(),
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'reference_number' => Yii::t('site', 'Reference Number'),
            'first_name' => Yii::t('site', 'First Name'),
            'second_name' => Yii::t('site', 'Second Name'),
            'third_name' => Yii::t('site', 'Third Name'),
            'family_name' => Yii::t('site', 'Family Name'),
            'email' => Yii::t('site', 'Email'),
            'mobile_number' => Yii::t('site', 'Mobile Number'),
            'programe_type' => Yii::t('site', 'Programe Type'),
            'class_type' => Yii::t('site', 'Class Type'),
            'home_phone' => Yii::t('site', 'Home Phone'),
            'home_fax' => Yii::t('site', 'Home Fax'),
            'work_city' => Yii::t('site', 'Work City'),
            'work_district' => Yii::t('site', 'Work District'),
            'work_street' => Yii::t('site', 'Work Street'),
            'work_building_number' => Yii::t('site', 'Work Building Number'),
            'family_book_file' => Yii::t('site', 'Family Book File'),
            'identity_file' => Yii::t('site', 'Identity File'),
            'gender' => Yii::t('site', 'Gender'),
            'date_of_birth' => Yii::t('site', 'Date Of Birth'),
            'social_status' => Yii::t('site', 'Social Status'),
            'proof of personality' => Yii::t('site', 'Proof Of Personality'),
            'home_city' => Yii::t('site', 'Home City'),
            'diseases_list' => Yii::t('site', 'Diseases List'),
            'created' => Yii::t('site', 'Created'),
            'updated' => Yii::t('site', 'Updated'),
            'initial_price' => Yii::t('site', 'Initial Price'),
            'discount' => Yii::t('site', 'Discount'),
            'final_price' => Yii::t('site', 'Final Price'),
            'request_status' => Yii::t('site', 'Request Status'),
            'reject_reason' => Yii::t('site', 'Reject Reason'),
            'payment_method' => Yii::t('site', 'Payment Method'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIndividualMedicalInsuranceFamilyLists()
    {
        return $this->hasMany(IndividualMedicalInsuranceFamilyList::className(), ['parent_number' => 'id']);
    }

    /**
     * {@inheritdoc}
     * @return IndividualMedicalInsuranceQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new IndividualMedicalInsuranceQuery(get_called_class());
    }
}
