<?php

namespace backend\modules\quotes_request\models\search;

use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\modules\quotes_request\models\MotorInsurance;

/**
 * MotorInsuranceSearch represents the model behind the search form about `backend\modules\quotes_request\models\MotorInsurance`.
 */
class MotorInsuranceSearch extends MotorInsurance
{
    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id', 'amount_of_insurance', 'created', 'updated'], 'integer'],
            [['reference_number', 'first_name', 'second_name', 'third_name', 'family_name', 'email', 'mobile_number', 'registration_status', 'vehicle_type', 'car_model', 'manufacturing_year', 'fuel_type', 'repair_agency', 'name_of_insured', 'via', 'beneficiary_name', 'city', 'district', 'street', 'building_number', 'home_number', 'gender', 'date_of_birth', 'career', 'plate_Number', 'vin_number', 'engine_serial_number', 'national_number', 'registration_number', 'driving_license_file', 'Identity_commercial_file', 'request_status'], 'safe'],
            [['initial_price', 'final_price'], 'number'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = MotorInsurance::find();

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => Yii::$app->request->cookies->getValue('_grid_page_size', 20),
            ],
            'sort' => [
                'defaultOrder' => [
                    'id' => SORT_DESC,
                ],
            ],
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        $query->andFilterWhere([
            'id' => $this->id,
            'manufacturing_year' => $this->manufacturing_year,
            'amount_of_insurance' => $this->amount_of_insurance,
            'date_of_birth' => $this->date_of_birth,
            'created' => $this->created,
            'updated' => $this->updated,
            'initial_price' => $this->initial_price,
            'final_price' => $this->final_price,
        ]);

        $query->andFilterWhere(['like', 'reference_number', $this->reference_number])
            ->andFilterWhere(['like', 'first_name', $this->first_name])
            ->andFilterWhere(['like', 'second_name', $this->second_name])
            ->andFilterWhere(['like', 'third_name', $this->third_name])
            ->andFilterWhere(['like', 'family_name', $this->family_name])
            ->andFilterWhere(['like', 'email', $this->email])
            ->andFilterWhere(['like', 'mobile_number', $this->mobile_number])
            ->andFilterWhere(['like', 'registration_status', $this->registration_status])
            ->andFilterWhere(['like', 'vehicle_type', $this->vehicle_type])
            ->andFilterWhere(['like', 'car_model', $this->car_model])
            ->andFilterWhere(['like', 'fuel_type', $this->fuel_type])
            ->andFilterWhere(['like', 'repair_agency', $this->repair_agency])
            ->andFilterWhere(['like', 'name_of_insured', $this->name_of_insured])
            ->andFilterWhere(['like', 'via', $this->via])
            ->andFilterWhere(['like', 'beneficiary_name', $this->beneficiary_name])
            ->andFilterWhere(['like', 'city', $this->city])
            ->andFilterWhere(['like', 'district', $this->district])
            ->andFilterWhere(['like', 'street', $this->street])
            ->andFilterWhere(['like', 'building_number', $this->building_number])
            ->andFilterWhere(['like', 'home_number', $this->home_number])
            ->andFilterWhere(['like', 'gender', $this->gender])
            ->andFilterWhere(['like', 'career', $this->career])
            ->andFilterWhere(['like', 'plate_Number', $this->plate_Number])
            ->andFilterWhere(['like', 'vin_number', $this->vin_number])
            ->andFilterWhere(['like', 'engine_serial_number', $this->engine_serial_number])
            ->andFilterWhere(['like', 'national_number', $this->national_number])
            ->andFilterWhere(['like', 'registration_number', $this->registration_number])
            ->andFilterWhere(['like', 'driving_license_file', $this->driving_license_file])
            ->andFilterWhere(['like', 'Identity_commercial_file', $this->Identity_commercial_file])
            ->andFilterWhere(['like', 'request_status', $this->request_status]);

        return $dataProvider;
    }
}
