<?php


use backend\modules\quotes_criteria\models\CarModel;
use backend\modules\quotes_request\forms\MotorInsuranceForm;
use borales\extensions\phoneInput\PhoneInput;
use common\helpers\Utility;
use kartik\builder\Form;
use kartik\builder\FormGrid;
use kartik\helpers\Html;
use kartik\number\NumberControl;
use kartik\widgets\ActiveForm;
use kartik\widgets\DepDrop;
use yii\helpers\ArrayHelper;
use yii\helpers\Url;

/* @var $model \backend\modules\quotes_request\forms\MotorInsuranceForm */

?>

<div class="motor-insurance-form">

    <div class="row">
        <div class="col-md-9">

            <?php
            $form = ActiveForm::begin([
                'options' => ['enctype' => 'multipart/form-data'],
                'id' => 'motor-stage-one-form',
                //'action' => ['/quote/motor-stage-one'],
                'type' => ActiveForm::TYPE_VERTICAL,
                'enableAjaxValidation' => true
            ]); ?>
            <?php echo Html::activeHiddenInput($model, 'id') ?>
            <?php
            try {
                $quoteForm1 = Form::widget([
                    'model' => $model,
                    'form' => $form,
                    'columns' => 4,
                    'attributes' => [
                        'first_name' => [
                            'label' => false,
                            'options' => ['placeholder' => $model->getAttributeLabel('first_name')],
                        ],
                        'second_name' => [
                            'label' => false,
                            'options' => ['placeholder' => $model->getAttributeLabel('second_name')],

                        ],
                        'third_name' => [
                            'label' => false,
                            'options' => ['placeholder' => $model->getAttributeLabel('third_name')],

                        ],
                        'family_name' => [
                            'label' => false,
                            'options' => ['placeholder' => $model->getAttributeLabel('family_name')],

                        ],
                        'email' => [
                            'label' => false,
                            'options' => ['placeholder' => $model->getAttributeLabel('email')],

                        ],
                        'mobile_number' => [
                            'label' => false,
                            'type' => Form::INPUT_WIDGET,
                            'widgetClass' => PhoneInput::className(),
                            'options' => [
                                'jsOptions' => [
                                    'initialCountry' => 'JO', // auto not working
                                    'placeholderNumberType' => 'MOBILE',
                                    'nationalMode' => false,
                                ]
                            ]
                        ],
                    ]
                ]);
                $quoteForm2 = Form::widget([
                    'model' => $model,
                    'form' => $form,
                    'columns' => 4,
                    'attributes' => [

                        'registration_status' => [
                            'label' => false,
                            'type' => Form::INPUT_WIDGET,
                            'options' => [
                                'options' => [
                                    'placeholder' => $model->getAttributeLabel('registration_status'),
                                ],
                                'pluginOptions' => [
                                    'allowClear' => false
                                ],
                                'data' => MotorInsuranceForm::getRegistrationStatusList()
                            ],
                            'widgetClass' => '\kartik\widgets\Select2'
                        ],
                        'vehicle_type' => [
                            'label' => false,
                            'type' => Form::INPUT_WIDGET,
                            'options' => [
                                'options' => ['placeholder' => $model->getAttributeLabel('vehicle_type')],
                                'pluginOptions' => ['allowClear' => true],
                                'data' => MotorInsuranceForm::getVehicleTypeList()
                            ],
                            'widgetClass' => '\kartik\widgets\Select2'
                        ],
                        'car_model' => [
                            'label' => false,
                            'type' => Form::INPUT_WIDGET,
                            'widgetClass' => '\kartik\depdrop\DepDrop',
                            'select2Options' => ['pluginOptions' => ['allowClear' => true]],
                            'options' => [
                                'value' => '-',
                                'type' => DepDrop::TYPE_SELECT2,
                                'options' => ['placeholder' => $model->getAttributeLabel('car_model')],
                                'pluginOptions' => [
                                    'value' => '-',
                                    'placeholder' => $model->getAttributeLabel('car_model'),
                                    'depends' => ['motorinsuranceform-vehicle_type'],
                                    'url' => Url::to(['get-car-model']),
                                ],
                                'data' => ArrayHelper::map(CarModel::find()->joinWith('translations')->where(['car_brand_id' => $model->vehicle_type])->all(), 'id', 'title')
                            ],
                        ],
                        'manufacturing_year' => [
                            'label' => false,
                            'type' => Form::INPUT_WIDGET,
                            'options' => [
                                'options' => ['placeholder' => $model->getAttributeLabel('manufacturing_year')],
                                'pluginOptions' => ['allowClear' => true],
                                'data' => MotorInsuranceForm::getYearList()
                            ],
                            'widgetClass' => '\kartik\widgets\Select2'
                        ],
                        'fuel_type' => [
                            'label' => false,
                            'type' => Form::INPUT_WIDGET,
                            'options' => [
                                'options' => ['placeholder' => $model->getAttributeLabel('fuel_type')],
                                'pluginOptions' => ['allowClear' => true],
                                'data' => MotorInsuranceForm::getFuelTypeList()
                            ],
                            'widgetClass' => '\kartik\widgets\Select2'
                        ],
                        'repair_agency' => [
                            'label' => false,
                            'type' => Form::INPUT_WIDGET,
                            'options' => [
                                'options' => ['placeholder' => $model->getAttributeLabel('repair_agency')],
                                'pluginOptions' => ['allowClear' => true],
                                'data' => Utility::getYesNoList()
                            ],
                            'widgetClass' => '\kartik\widgets\Select2'
                        ],
//                            'amount_of_insurance' => [
//                                'label' => false,
//                                'type' => Form::INPUT_TEXT,
//                                'options' => ['placeholder' => $model->getAttributeLabel('amount_of_insurance')],
//                            ],
                        'amount_of_insurance' => [
                            'label' => false,
                            'type' => Form::INPUT_WIDGET,
                            'options' => [
                                'displayOptions' => [
                                    'placeholder' => $model->getAttributeLabel('amount_of_insurance'),
                                    'class' => 'form-control kv-monospace'
                                ],
                                'maskedInputOptions' => [
                                    'prefix' => 'JD ',
//                                        'min' => 1,
//                                        'max' => 120000
                                ],
                            ],
                            'widgetClass' => NumberControl::className()
                        ],
                    ]
                ]);

            } catch (Exception $e) {
                var_dump($e->getMessage());
                die();
            }
            try {
                $quoteForm3 = Form::widget([
                    'model' => $model,
                    'form' => $form,
                    'columns' => 4,
                    'attributes' => [
                        'name_of_insured' => [
                            'label' => false,
                            'options' => ['placeholder' => $model->getAttributeLabel('name_of_insured')],
                        ],
                        'via' => [
                            'label' => false,
                            'options' => ['placeholder' => $model->getAttributeLabel('via')],

                        ],
                        'beneficiary_name' => [
                            'label' => false,
                            'options' => ['placeholder' => $model->getAttributeLabel('beneficiary_name')],

                        ],
                    ]
                ]);
                $quoteForm4 = Form::widget([
                    'model' => $model,
                    'form' => $form,
                    'columns' => 4,
                    'attributes' => [

                        'city' => [
                            'label' => false,
                            'type' => Form::INPUT_WIDGET,
                            'options' => [
                                'options' => [
                                    'placeholder' => $model->getAttributeLabel('city'),
                                ],
                                'pluginOptions' => [
                                    'allowClear' => false
                                ],
                                'data' => Utility::getCityList()
                            ],
                            'widgetClass' => '\kartik\widgets\Select2'
                        ],
                        'district' => [
                            'label' => false,
                            'type' => Form::INPUT_WIDGET,
                            'options' => [
                                'options' => ['placeholder' => $model->getAttributeLabel('district')],
                                'pluginOptions' => ['allowClear' => true],
                                'data' => Utility::getDistrictList()
                            ],
                            'widgetClass' => '\kartik\widgets\Select2'
                        ],
                        'street' => [
                            'label' => false,
                            'type' => Form::INPUT_WIDGET,
                            'options' => [
                                'options' => ['placeholder' => $model->getAttributeLabel('street')],
                                'pluginOptions' => ['allowClear' => true],
                                'data' => Utility::getStreetList()
                            ],
                            'widgetClass' => '\kartik\widgets\Select2'
                        ],
                        'building_number' => [
                            'label' => false,
                            'options' => ['placeholder' => $model->getAttributeLabel('building_number')],
                        ],
                        'home_number' => [
                            'label' => false,
                            'options' => ['placeholder' => $model->getAttributeLabel('home_number')],
                        ],
                        'gender' => [
                            'label' => false,
                            'type' => Form::INPUT_WIDGET,
                            'options' => [
                                'options' => ['placeholder' => $model->getAttributeLabel('gender')],
                                'pluginOptions' => ['allowClear' => true],
                                'data' => \common\helpers\Utility::getGenderList()
                            ],
                            'widgetClass' => '\kartik\widgets\Select2'
                        ],
                        'date_of_birth' => [
                            'label' => false,
                            'type' => Form::INPUT_WIDGET,
                            'options' => [
                                'options' => ['placeholder' => $model->getAttributeLabel('date_of_birth')],
                                'pluginOptions' => [
                                    'format' => 'yyyy-mm-dd'
                                ],
                            ],
                            'widgetClass' => \kartik\widgets\DatePicker::className()
                        ],
                        'career' => [
                            'label' => false,
                            'options' => ['placeholder' => $model->getAttributeLabel('career')],
                        ],
                    ]
                ]);

                $quoteForm5 = FormGrid::widget([
                    'model' => $model,
                    'form' => $form,
                    'autoGenerateColumns' => true,
                    'rows' => [
                        [
                            'attributes' => [
                                'plate_Number' => [
                                    'label' => false,
                                    'options' => ['placeholder' => $model->getAttributeLabel('plate_Number')],

                                ],
                                'vin_number' => [
                                    'label' => false,
                                    'options' => ['placeholder' => $model->getAttributeLabel('vin_number')],

                                ],
                                'engine_serial_number' => [
                                    'label' => false,
                                    'options' => [
                                        'disabled' => $model->fuel_type == 'Electricity' ? true : false,
                                        'placeholder' => $model->getAttributeLabel('engine_serial_number')
                                    ],

                                ],
                            ]
                        ],
                        [
                            'attributes' => [
                                'national_number' => [
                                    'label' => false,
                                    'options' => ['placeholder' => $model->getAttributeLabel('national_number')],

                                ],
                                'registration_number' => [
                                    'label' => false,
                                    'options' => ['placeholder' => $model->getAttributeLabel('registration_number')],

                                ],
                            ]
                        ],
                        [
                            'attributes' => [
                                'driving_license_file' => [
                                    'label' => false,
                                    'type' => Form::INPUT_WIDGET,
                                    'widgetClass' => '\kartik\widgets\FileInput',
                                    'options' => [
                                        'options' => [
                                            'multiple' => false,
                                        ],
                                        'pluginOptions' => [
                                            'initialCaption' => $model->getAttributeLabel('registration_number'),
                                            'maxFileCount' => 1,
                                            'maxFileSize' => 5120,
                                            'showUpload' => false,
                                            'showPreview' => false,
                                        ]
                                    ]
                                ],
                                'Identity_commercial_file' => [
                                    'label' => false,
                                    'type' => Form::INPUT_WIDGET,
                                    'widgetClass' => '\kartik\widgets\FileInput',
                                    'options' => [
                                        'options' => [
                                            'multiple' => false,
                                        ],
                                        'pluginOptions' => [
                                            'initialCaption' => $model->getAttributeLabel('Identity_commercial_file'),
                                            'maxFileCount' => 1,
                                            'maxFileSize' => 5120,
                                            'showUpload' => false,
                                            'showPreview' => false,
                                        ]
                                    ]
                                ],
                            ],
                        ]
                    ]
                ]);

            } catch (Exception $e) {
                var_dump($e->getMessage());
                die();
            }


            echo Html::panel(
                ['body' => '<div class="panel-body">' . $quoteForm1 . '</div>', 'heading' => Yii::t('site', 'Basic Information')],
                Html::TYPE_DEFAULT
            );
            echo Html::panel(
                ['body' => '<div class="panel-body">' . $quoteForm2 . '</div>', 'heading' => Yii::t('site', 'Vehicle Information')],
                Html::TYPE_DEFAULT
            );
            echo Html::panel(
                ['body' => '<div class="panel-body">' . $quoteForm3 . '</div>', 'heading' => Yii::t('site', 'Insured data')],
                Html::TYPE_DEFAULT
            );

            echo Html::panel(
                ['body' => '<div class="panel-body">' . $quoteForm4 . '</div>', 'heading' => Yii::t('site', 'Address Information')],
                Html::TYPE_DEFAULT
            );
            echo Html::panel(
                ['body' => '<div class="panel-body">' . $quoteForm5 . '</div>', 'heading' => Yii::t('site', 'Vehicle Information')],
                Html::TYPE_DEFAULT
            );
            ?>

        </div>

        <div class="col-md-3">

            <div class="panel panel-default">
                <div class="panel-body">
                    <div class="record-info">
                        <div class="form-group clearfix">
                            <label class="control-label" style="float: left; padding-right: 5px;"><?=  $model->attributeLabels()['id'] ?>: </label>
                            <span><?=  $model->id ?></span>
                        </div>
                        <div class="form-group clearfix">
                            <label class="control-label" style="float: left; padding-right: 5px;"><?=  $model->attributeLabels()['reference_number'] ?>: </label>
                            <span><?=  $model->reference_number ?></span>
                        </div>
                        <div class="form-group clearfix">
                            <label class="control-label" style="float: left; padding-right: 5px;"><?=  $model->attributeLabels()['created'] ?>: </label>
                            <span><?=  Yii::$app->formatter->asDate($model->created) . ' ' . Yii::$app->formatter->asTime($model->created)  ?></span>
                        </div>
                        <div class="form-group clearfix">
                            <label class="control-label" style="float: left; padding-right: 5px;"><?=  $model->attributeLabels()['updated'] ?>: </label>
                            <span><?=  Yii::$app->formatter->asDate($model->updated) . ' ' . Yii::$app->formatter->asTime($model->updated) ?></span>
                        </div>
                        <div class="form-group clearfix">
                            <label class="control-label" style="float: left; padding-right: 5px;"><?=  $model->attributeLabels()['initial_price'] ?>: </label>
                            <span><?=  $model->initial_price ?></span>
                        </div>
                        <div class="form-group clearfix">
                            <span><?= $form->field($model, 'payment_method')->widget(\kartik\select2\Select2::className(),[
                                    'options' => [
                                        'placeholder' => $model->getAttributeLabel('payment_method'),
                                    ],'data' => MotorInsuranceForm::getPaymentMethodList()
                                ]) ?></span>
                        </div>

                        <div class="form-group">
                            <?php  if ($model->isNewRecord): ?>
                                <?= Html::submitButton(Yii::t('yee', 'Create'), ['class' => 'btn btn-primary']) ?>
                                <?= Html::a(Yii::t('yee', 'Cancel'), ['/quotes_request/motor/index'], ['class' => 'btn btn-default']) ?>
                            <?php  else: ?>
                                <?= Html::submitButton(Yii::t('yee', 'Save'), ['class' => 'btn btn-primary']) ?>
                                <?= Html::a(Yii::t('yee', 'Delete'),
                                    ['/quotes_request/motor/delete', 'id' => $model->id], [
                                        'class' => 'btn btn-default',
                                        'data' => [
                                            'confirm' => Yii::t('yii', 'Are you sure you want to delete this item?'),
                                            'method' => 'post',
                                        ],
                                    ]) ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>

        </div>

        <?php ActiveForm::end(); ?>
    </div>

</div>