<?php

namespace backend\modules\signupuser\models;

use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\db\ActiveRecord;
use yeesoft\media\models\Media;
use yeesoft\models\User;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\TimestampBehavior;
use yii\helpers\Html;

/**
 * This is the model class for table "signupuser".
 *
 * @property int $id
 * @property int $status 9-pending,10-active
 * @property int $published_at
 * @property int $created_at
 * @property int $updated_at
 */
class Signupuser extends ActiveRecord
{

    const STATUS_PENDING = 9;
    const STATUS_ACTIVE = 10;
    const TYPE_DEALER = 2;
    const TYPE_USER = 1;
    const DOCUMENT_REVIEW = 0;
    const DOCUMENT_APPROVED = 1;
    const DOCUMENT_REJECTED = 2;

    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'users';
    }

    /**
     * @inheritdoc
     */
    // public function behaviors()
    // {
    //     return [
    //         TimestampBehavior::className(),
    //         BlameableBehavior::className(),
    //         'multilingual' => [
    //             'class' => MultilingualBehavior::className(),
    //             'langForeignKey' => 'parent_id',
    //             'tableName' => "{{%announcement_lang}}",
    //             'attributes' => [
    //                 'title', 'brief', 'content',
    //             ]
    //         ],
    //     ];
    // }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['name'], 'required'],
			[['name','email', 'phone'], 'required'],
            [[ 'status','is_document_approved'], 'integer'],
            [['created_at', 'updated_at'], 'safe'],
			[[ 'email'], 'string', 'max' => 50],
			[[ 'email'], 'email'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'name'=>Yii::t('site', 'Name'),
            'email'=>Yii::t('site', 'Email'),
            'phone'=>Yii::t('site', 'Phone'),
            'status'=>Yii::t('site', 'Status'),
            'is_document_approved'=>Yii::t('site', 'Document'),
            'created_at' => Yii::t('site', 'Created At'),
            'updated_at' => Yii::t('site', 'Updated At'),

        ];
    }

    /**
     * {@inheritdoc}
     * @return SignupuserQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new SignupuserQuery(get_called_class());
    }



    public function getCreatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->updated_at);
    }


    public function getCreatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getCreatedDatetime()
    {
        return "{$this->createdDate} {$this->createdTime}";
    }

    public function getUpdatedDatetime()
    {
        return "{$this->updatedDate} {$this->updatedTime}";
    }

    public function getStatusText()
    {
        return $this->getStatusList()[$this->status];
    }

    /**
     * getTypeList
     * @return array
     */
    public static function getStatusList()
    {
        return [
            self::STATUS_PENDING => Yii::t('yee', 'Pending'),
            self::STATUS_ACTIVE => Yii::t('yee', 'Active'),
        ];
    }
    public static function getTypeList()
    {
        return [
            self::TYPE_DEALER => Yii::t('yee', 'Dealer'),
            self::TYPE_USER => Yii::t('yee', 'User'),
        ];
    }
    public static function getDocumentApproved()
    {
        return [
            self::DOCUMENT_REVIEW => Yii::t('yee', 'REVIEW'),
            self::DOCUMENT_APPROVED => Yii::t('yee', 'APPROVED'),
            self::DOCUMENT_REJECTED => Yii::t('yee', 'REJECTED'),
        ];
    }
    /**
     * getStatusOptionsList
     * @return array
     */
    public static function getStatusOptionsList()
    {
        return [
            [self::STATUS_PENDING, Yii::t('yee', 'Pending'), 'default'],
            [self::STATUS_ACTIVE, Yii::t('yee', 'Active'), 'primary']
        ];
    }

    /**
     * getCommentStatusList
     * @return array
     */

    /**
     *
     * @inheritdoc
     */
    public static function getFullAccessPermission()
    {
        return 'fullPageAccess';
    }

    /**
     * @return Media
     */
    public function getMediaRefObj($fieldName)
    {
        $imgRefObj = Media::findOne(['url' => $this->$fieldName]);

        return $imgRefObj;
    }


    public function save($runValidation = true, $attributeNames = null)
    {
        \Yii::$app->cache->flush();
        return parent::save($runValidation, $attributeNames);
    }

}
