<?php

use yii\helpers\Html;
use yii\widgets\Pjax;
use kartik\grid\GridView;

/* @var $this \yii\web\View */
/* @var $language_id string */
/* @var $dataProvider yii\data\ActiveDataProvider */
/* @var $searchModel lajax\translatemanager\models\searches\LanguageSourceSearch */
/* @var $searchEmptyCommand string */

$this->title = Yii::t('language', 'Translation into {language_id}',
    ['language_id' => $language_id]);
$this->params['breadcrumbs'][] = ['label' => Yii::t('language', 'Languages'),
    'url' => ['list']];
$this->params['breadcrumbs'][] = $this->title;
$this->registerCss('.pagination {
	 margin: 0 0 5px 0; 
}');
\Yii::$app->assetManager->bundles = [
    'yii\bootstrap\BootstrapAsset' => [
        'css' => [],
    ],
];
?>
    <div class="table-responsive kv-grid-container backend-footer-pagination">
    <?= Html::hiddenInput('language_id', $language_id, ['id' => 'language_id',
        'data-url' => Yii::$app->urlManager->createUrl('/translatemanager/translator/save')]); ?>
    <div id="translates" class="<?= $language_id ?>">
        <?php
        Pjax::begin([
            'id' => 'translates',
        ]);
        echo GridView::widget([
            'dataProvider' => $dataProvider,
            'filterModel' => $searchModel,
            'layout' => "<div class='col-md-12'>{items}</div><div class='col-md-8 text-center'><br>
<br>{pager}<br><br></div><div class='col-md-3 text-right hidden'>{summary}</div>",
            'columns' => [
                ['class' => 'yii\grid\SerialColumn'],
                [
                    'format' => 'raw',
                    'attribute' => 'message',
                    'filterInputOptions' => ['class' => 'form-control', 'id' => 'message'],
                    'label' => Yii::t('language', 'Source'),
                    'content' => function ($data) {
                        return Html::textarea('LanguageSource[' . $data->id . ']',
                            $data->message, ['class' => 'form-control source', 'readonly' => 'readonly']);
                    },
                ],
                [
                    'format' => 'raw',
                    'attribute' => 'translation',
                    'filterInputOptions' => [
                        'class' => 'form-control',
                        'id' => 'translation',
                        'placeholder' => $searchEmptyCommand ? Yii::t('language',
                            'Enter "{command}" to search for empty translations.',
                            ['command' => $searchEmptyCommand]) : '',
                    ],
                    'label' => Yii::t('language', 'Translation'),
                    'content' => function ($data) {
                        return Html::textarea('LanguageTranslate[' . $data->id . ']'
                            , $data->translation, ['class' => 'form-control translation',
                                'data-id' => $data->id, 'tabindex' => $data->id]);
                    },
                ],
                [
                    'format' => 'raw',
                    'label' => Yii::t('language', 'Action'),
                    'content' => function ($data) {
                        return Html::button(Yii::t('language', 'Save'),
                            ['type' => 'button', 'data-id' => $data->id, 'class' => 'btn btn-primary']);
                    },
                ],
            ],
            'toolbar'=> [
                ['content'=>Html::a(Yii::t('app','Back'),
                    ['/translatemanager/translator'], ['class' => 'btn btn-default'])],
            ],
            'striped' => true,
            'condensed' => true,
            'responsive' => true,
            'panel' => [
                'type' => 'default',
            ]
        ]);
        Pjax::end();
        ?>
    </div>
</div>