<?php

namespace backend\modules\vehicle\models;

use backend\modules\dropdown_list\models\DropdownList;
use Yii;

/**
 * This is the model class for table "vehicle_attachment".
 *
 * @property int $vehicle_id
 * @property int $attachment_id
 *
 * @property Vehicle $vehicle
 * @property DropdownList $attachment
 */
class VehicleAttachment extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'vehicle_attachment';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['vehicle_id', 'attachment_id'], 'required'],
            [['vehicle_id', 'attachment_id'], 'integer'],
            [['vehicle_id', 'attachment_id'], 'unique', 'targetAttribute' => ['vehicle_id', 'attachment_id']],
            [['vehicle_id'], 'exist', 'skipOnError' => true, 'targetClass' => Vehicle::className(), 'targetAttribute' => ['vehicle_id' => 'id']],
            [['attachment_id'], 'exist', 'skipOnError' => true, 'targetClass' => DropdownList::className(), 'targetAttribute' => ['attachment_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'vehicle_id' => Yii::t('site', 'Vehicle ID'),
            'attachment_id' => Yii::t('site', 'Attachment ID'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getVehicle()
    {
        return $this->hasOne(Vehicle::className(), ['id' => 'vehicle_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getAttachment()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'attachment_id']);
    }

    /**
     * {@inheritdoc}
     * @return VehicleAttachmentQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new VehicleAttachmentQuery(get_called_class());
    }
}
