<?php

namespace yeesoft\auth\models\forms;

use borales\extensions\phoneInput\PhoneInputValidator;
use common\helpers\JPA_WS\JPA_WS;
use common\helpers\ZainSms;
use kartik\password\StrengthValidator;
use yeesoft\models\User;
use Yii;
use yii\base\Model;
use yii\helpers\Html;

class SignupForm extends Model
{
    public $first_name;
    public $last_name;
    public $phone;
    public $username;
    public $email;
    public $password;
    public $repeat_password;
    public $captcha;
    public $city_id;

    /**
     * @inheritdoc
     */
    public function rules()
    {
        $rules = [
//            ['captcha', 'captcha'],
            [['username',
                'password', 'repeat_password'/*, 'first_name', 'last_name'*/], 'required'],
            [['username', 'email', 'password', 'repeat_password'], 'trim'],
            [['email', /*'username'*/], 'email'],
            [['city_id'], 'integer'],
            ['username', 'unique',
                'targetClass' => 'yeesoft\models\User',
                'targetAttribute' => 'username',
            ],
            ['email', 'unique',
                'targetClass' => 'yeesoft\models\User',
                'targetAttribute' => 'email',
            ],
//            ['username', 'purgeXSS'],
            [['phone', 'first_name', 'last_name'], 'string', 'max' => 50],
//            ['username', 'match', 'pattern' => Yii::$app->yee->usernameRegexp, 'message' => Yii::t('yee/auth', 'The username should contain only Latin letters, numbers and the following characters: "-" and "_".')],
//            ['username', 'match', 'not' => true, 'pattern' => Yii::$app->yee->usernameBlackRegexp, 'message' => Yii::t('yee/auth', 'Username contains not allowed characters or words.')],
            [['password'], 'string', 'max' => 255],
            [['username'], 'integer'],
            ['repeat_password', 'compare', 'compareAttribute' => 'password'],
            [['phone'], PhoneInputValidator::className()],
            [['password'], StrengthValidator::className(),
                'min' => Yii::$app->params['password_min'],
                'upper' => Yii::$app->params['password_upper'],
                'lower' => Yii::$app->params['password_lower'],
                'digit' => Yii::$app->params['password_digit'],
                'special' => Yii::$app->params['password_special'],
                'hasUser' => Yii::$app->params['password_hasUser'],
                'hasEmail' => Yii::$app->params['password_hasEmail']
            ],

        ];

        return $rules;
    }

    /**
     * Remove possible XSS stuff
     *
     * @param $attribute
     */
    public function purgeXSS($attribute)
    {
        $this->$attribute = Html::encode($this->$attribute);
    }

    /**
     * @return array
     */
    public function attributeLabels()
    {
        return [
            'username' => Yii::t('site', 'ID Number'),
            'first_name' => Yii::t('site', 'First Name *'),
            'last_name' => Yii::t('site', 'Last Name *'),
            'email' => Yii::t('site', 'E-mail *'),
            'password' => Yii::t('site', 'Password *'),
            'repeat_password' => Yii::t('site', 'Repeat password *'),
            'captcha' => Yii::t('site', 'Captcha'),
            'city_id' => Yii::t('site', 'City'),
        ];
    }

    /**
     * @param bool $performValidation
     *
     * @return bool|User
     */
    public function signup($performValidation = true)
    {
        if ($performValidation AND !$this->validate()) {
            return false;
        }

        $user = new User();
        $user->password = $this->password;
        $user->username = $this->username;
//        $user->email = null;
//        $user->first_name = $this->first_name;
//        $user->last_name = $this->last_name;
//        $user->phone = $this->phone;


        if (Yii::$app->yee->smsConfirmationRequired) {
            $user->status = User::STATUS_INACTIVE;
            $user->generateConfirmationToken();
            $responseJSON = JPA_WS::getMobile($user->username);

            if (!$this->sendConfirmationSMS($user)) {
                $this->addError('username', Yii::t('site', 'Could not send confirmation sms'));
            }
        }

        if (!$user->save()) {
            $this->addError('username', Yii::t('site', 'Login has been taken'));
        } else {
            return $user;
        }

        return FALSE;
    }

    /**
     * @param User $user
     *
     * @return bool
     */
    protected function sendConfirmationSMS($user)
    {

        $parts = explode('_', $user->confirmation_token);
        $smsCode = (int) ($parts[0]);

        ZainSms::Send('', $smsCode);

        return true;
    }

    /**
     * @param User $user
     *
     * @return bool
     */
    protected function sendConfirmationEmail($user)
    {
        return Yii::$app->mailer->compose(Yii::$app->yee->emailTemplates['signup-confirmation'], ['user' => $user])
            ->setFrom(Yii::$app->yee->emailSender)
            ->setTo($user->email)
            ->setSubject(Yii::t('site', 'E-mail confirmation for') . ' ' . Yii::$app->name)
            ->send();
    }

    /**
     * Check received confirmation token and if user found - activate it, set username, roles and log him in
     *
     * @param string $token
     *
     * @return bool|User
     */
    public function checkConfirmationToken($token)
    {
        $user = User::findInactiveByConfirmationToken($token);

        if ($user) {

            $user->status = User::STATUS_ACTIVE;
            $user->email_confirmed = 1;
            $user->removeConfirmationToken();
            $user->save(false);
            $user->assignRoles(Yii::$app->yee->defaultRoles);
            Yii::$app->user->login($user);

            return $user;
        }

        return false;
    }
}