<?php

namespace common\models;

use Yii;
use yii\db\Expression;

/**
 * This is the model class for table "dropdown_list_lang".
 *
 * @property int $id
 * @property int $parent_id
 * @property string $language
 * @property string|null $title
 *
 * @property DropdownList $parent
 */
class DropdownListLang extends \yii\db\ActiveRecord
{
    const LANGUAGE_EN = 'en';
    const LANGUAGE_AR = 'ar';
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'dropdown_list_lang';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['id', 'parent_id', 'language'], 'required'],
            [['id', 'parent_id'], 'integer'],
            [['title'], 'string'],
            [['language'], 'string', 'max' => 6],
            [['id'], 'unique'],
            [['parent_id'], 'exist', 'skipOnError' => true, 'targetClass' => DropdownList::className(), 'targetAttribute' => ['parent_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'parent_id' => 'Parent ID',
            'language' => 'Language',
            'title' => 'Title',
        ];
    }

    /**
     * Gets query for [[Parent]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getParent()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'parent_id']);
    }


    public function manufacture()
    {
        $list = $this->getDropdownListWithIcon('VehicleManufacturer');
        return $list;
        /*$model =  \yii\helpers\ArrayHelper::map(\common\models\DropdownList::find()->where(['category' => 'VehicleManufacturer'])->orderBy(['slug' => SORT_ASC])->all(),'id','slugNameWithIcon');

        return $model;*/
    }

    public function subManufacture()
    {
        $model =  \yii\helpers\ArrayHelper::map(\common\models\DropdownList::find()->where(['category' => 'VehicleModelManufacturer'])->orderBy(['slug' => SORT_ASC])->all(),'id','slugName');

        if($id = Yii::$app->request->get('manufacturer_id')){
            $countModel = DropdownList::find()->where(['category'=>'VehicleModelManufacturer'])->andWhere(['parent_id'=>$id])->count();

            $model = DropdownList::find()->where(['category'=>'VehicleModelManufacturer'])->andWhere(['parent_id'=>$id])->orderBy(['slug'=>SORT_ASC])->all();
            $data = [];

            if ($countModel > 0){
                foreach ($model as $key){
                    $data[$key->id] = Yii::t('auto',$key->slugName);
                }
                asort($data);
                return $data;
            }
        }

        return $model;
    }

    public function transmission()
    {
        $list = $this->getDropdownListWithIcon('VehicleTransmission');
        return $list;

        /*$model =  \yii\helpers\ArrayHelper::map(\common\models\DropdownList::find()->where(['category' => 'VehicleTransmission'])->orderBy(['slug' => SORT_ASC])->all(),'id','slugNameWithIcon');
        return $model;*/

    }

    public function bodyType()
    {
        $list = $this->getDropdownListWithIcon('VehicleBodyType');
        return $list;
        /*$model =  \yii\helpers\ArrayHelper::map(\common\models\DropdownList::find()->where(['category' => 'VehicleBodyType'])->orderBy(['slug' => SORT_ASC])->all(),'id','slugNameWithIcon');

        return $model;*/
    }

    public function drive()
    {
        $list = $this->getDropdownListWithIcon('VehicleDrive');
        return $list;

       /* $model =  \yii\helpers\ArrayHelper::map(\common\models\DropdownList::find()->where(['category' => 'VehicleDrive'])->orderBy(['slug' => SORT_ASC])->all(),'id','slugNameWithIcon');
        return $model;*/
    }

    private function getDropdownListWithIcon($category){
        $lang = \Yii::$app->language;
        $url = Yii::$app->params['icons_image'];
        $list = \yii\helpers\ArrayHelper::map(Yii::$app->db->createCommand(
            "SELECT DF.id,DF.icon, DS.title from dropdown_list DF, dropdown_list_lang DS WHERE DF.id = DS.parent_id and DF.category  = '{$category}' and DS.language = '$lang' ORDER BY 
                                                        CASE 
                                                            WHEN DS.title = 'Other'
                                                            THEN 1
                                                            ELSE 0
                                                        END ASC
                                                     , DS.title ASC  ")->queryAll(),
            'id', function($d) use($url){
                if (Yii::$app->params['short_language2'] == Vehicle::ARABIC_LANGUAGE) {
                    return  $d['title'] .'<img class="form-selection-icon ml-2" src="' . $url . $d['icon'] . '" width = "22">';
                }else {
                    return '<img class="form-selection-icon" src="' . $url . $d['icon'] . '" width = "22">' . $d['title'];
                }

            });
        return $list;
    }

    public function getDropdownList($category){
        $lang = \Yii::$app->language;
        $list = \yii\helpers\ArrayHelper::map(Yii::$app->db->createCommand(
            "SELECT DF.id,DF.icon, DS.title from dropdown_list DF, dropdown_list_lang DS WHERE DF.id = DS.parent_id and DF.category  = '{$category}' and DS.language = '$lang' ORDER BY 
                                                        CASE 
                                                            WHEN DS.title = 'Other'
                                                            THEN 1
                                                            ELSE 0
                                                        END ASC,
                                                        CASE 
                                                            WHEN (DS.title = 'None' OR DS.title = 'لايوجد' OR DS.title = 'لا توجد ملاحظات')
                                                            THEN -1
                                                            ELSE 0
                                                        END ASC
                                                     , DS.title ASC  ")->queryAll(),
            'id', 'title');
        return $list;
    }

    private function getDropdownListWithSlugName($category){
        $lang = \Yii::$app->language;
        $list = \yii\helpers\ArrayHelper::map(Yii::$app->db->createCommand(
            "SELECT DF.id, DF.slug,DF.icon, DS.title from dropdown_list DF 
                LEFT JOIN dropdown_list_lang DS ON DF.id = DS.parent_id 
                WHERE  DF.category  = '{$category}' and DS.language = '$lang' ORDER BY 
                                                        CASE 
                                                            WHEN DS.title = 'Other'
                                                            THEN 1
                                                            ELSE 0
                                                        END ASC,
                                                        CASE 
                                                            WHEN (DS.title = 'None' OR DS.title = 'لايوجد' OR DS.title = 'لا توجد ملاحظات')
                                                            THEN -1
                                                            ELSE 0
                                                        END ASC
                                                     , DS.title ASC  ")->queryAll(),
            'id', function($d){
                return (!empty($d['title'])) ? $d['title'] : $d['slug'];
            });
        return $list;
    }

    private function getDropdownListWithColor($category){
        $lang = \Yii::$app->language;
        $list = \yii\helpers\ArrayHelper::map(Yii::$app->db->createCommand(
            "SELECT DF.id, DF.slug,DF.color_code, DS.title from dropdown_list DF 
                LEFT JOIN dropdown_list_lang DS ON DF.id = DS.parent_id 
                WHERE  DF.category  = '{$category}' and DS.language = '$lang' ORDER BY 
                                                        CASE 
                                                            WHEN DS.title = 'Other'
                                                            THEN 1
                                                            ELSE 0
                                                        END ASC,
                                                        CASE 
                                                            WHEN (DS.title = 'None' OR DS.title = 'لايوجد' OR DS.title = 'لا توجد ملاحظات')
                                                            THEN -1
                                                            ELSE 0
                                                        END ASC
                                                     , DS.title ASC  ")->queryAll(),
            'id', function($d){
                return '<span class="select2-color mr-2" style="background-color:' . $d['color_code'] . '; width: 20px;height: 20px; display: inline-block; position:relative; top: 3px;"></span>'. $d['title'];
            });

        return $list;
    }


    public function engine()
    {
        $list = $this->getDropdownListWithIcon('VehicleEngine');
        return $list;
        /*$model =  \yii\helpers\ArrayHelper::map(\common\models\DropdownList::find()->where(['category' => 'VehicleEngine'])->orderBy(['slug' => SORT_ASC])->all(),'id','slugNameWithIcon');
        echo "<pre>";print_r($model);echo "</pre>";die('Call');
        return $model;*/
    }

    public function cylinder()
    {
        $model =  \yii\helpers\ArrayHelper::map(\common\models\DropdownList::find()
            ->where(['category' => 'VehicleCylinders'])
            ->orderBy(new Expression("CAST(slug AS UNSIGNED), slug ASC"))
            ->all(),'id','cylinderName');
        return $model;
    }

    public function exteriorColor()
    {

        $list = $this->getDropdownListWithColor('VehicleColors');
        return $list;
        /*$model =  \yii\helpers\ArrayHelper::map(\common\models\DropdownList::find()->where(['category' => 'VehicleColors'])->orderBy(['slug' => SORT_ASC])->all(),'id','slugNameWithColor');

        return $model;*/
    }

    public function interiorColor()
    {
        $list = $this->getDropdownListWithColor('VehicleInteriorColor');
        return $list;
        /*$model =  \yii\helpers\ArrayHelper::map(\common\models\DropdownList::find()->where(['category' => 'VehicleInteriorColor'])->orderBy(['slug' => SORT_ASC])->all(),'id','slugNameWithColor');
        return $model;*/
    }

    public function equipment()
    {
        $list = $this->getDropdownListWithSlugName('VehicleEquipments');
        return $list;
        /*$model =  \yii\helpers\ArrayHelper::map(\common\models\DropdownList::find()->where(['category' => 'VehicleEquipments'])->orderBy(['slug' => SORT_ASC])->all(),'id','slugName');
        return $model;*/
    }

    public function remarks()
    {
        $list = $this->getDropdownListWithSlugName('VehicleRemarks');
        return $list;

        /*$model =  \yii\helpers\ArrayHelper::map(\common\models\DropdownList::find()->where(['category' => 'VehicleRemarks'])->orderBy(['slug' => SORT_ASC])->all(),'id','slugName');


        return $model;*/
    }

    public function airIntakeBoosterList()
    {
        $list = $this->getDropdownListWithSlugName('MeasuringTheDistance');
        return $list;
        /*$model =  \yii\helpers\ArrayHelper::map(\backend\modules\dropdown_list\models\DropdownList::find()->where(['status' => 1, 'category' => 'MeasuringTheDistance'])->all(),'id','title');
        return $model*/;
    }

    public function year()
    {
        for ($i = '1950'; $i<= '2000'; $i++)
        {
            echo $i ."<br>";
        }
        
    }

    public function vehicleType()
    {
        return [
            Vehicle::USED_CAR_FOR_SALE => Yii::t('auto','Used Car For Sale'),
            Vehicle::NEW_CAR_DEALS => Yii::t('auto','New Car Deals'),
            Vehicle::CERTIFIED_PRE_OWNED => Yii::t('auo','Certified Pre-Owned'),
        ];
    }

    public function price()
    {
        $range = [];
        for ($i=5000;$i<=350000;$i+=5000){
            $range[$i] = Yii::t('auto','{price} JOD',['price'=>$i]);
        }
        return $range;
    }

    public function distance()
    {
        $range = [];
        for ($i=0;$i<=100000;$i+=1000){
            $range[$i] = Yii::t('auto','{kilometer} KM',['kilometer'=>$i]);
        }
        return $range;
    }

    public function distanceMiles()
    {
        $range = [];
        for ($i=0;$i<=100000;$i+=1000){
            $range[$i] = Yii::t('auto','{miles} Miles',['miles'=>$i]);
        }
        return $range;
    }

}
