<?php

namespace common\models;

use common\models\Vehicle;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use yii\helpers\ArrayHelper;

/**
 * VehicleSearch represents the model behind the search form of `common\models\Vehicle`.
 */
use Yii;
class VehicleSearch extends Vehicle
{
    public $keyword;
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['id', 'user_id', 'phone_number', 'status', 'owner_id', 'owner_type_id', 'is_featured', 'vehicle_type', 'odometer_km', 'odometer_mile', 'front_left_status', 'front_right_status', 'back_left_status', 'back_right_status', 'body_type_id', 'cylinders_id', 'capacity', 'engine_id', 'power', 'rim_size', 'transmission_id', 'drive_id', 'image_counter', 'manufacturer_id', 'measuring_the_distance_id', 'created_at', 'updated_at', 'approved_at', 'created_by', 'updated_by', 'manufacturer_model_id', 'is_sold', 'car_type', 'is_accidental'], 'integer'],
            [['full_name', 'keyword', 'email', 'slug', 'title', 'model_year', 'color_id', 'interior_color_id', 'video_file', 'carseer_url', 'image360', 'phone', 'other_information', 'sell_as', 'remark', 'equipment', 'attachment', 'price_to', 'price_from', 'distance_km_from', 'distance_km_to', 'distance_mile_from', 'distance_mile_to'], 'safe'],
            [['price'], 'number'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $this->load($params,'');
        $sortBy = (!empty($params['sort'])) ? $params['sort'] : '';
        $sortByCol = 'id';
        $sortByDirection = 'DESC';
        switch ($sortBy){
            case 'price':
            case '-price':
                $sortByCol = 'price';
                $sortByDirection = (($sortBy == 'price') ? 'DESC' : 'ASC');
                break;
            case 'odometer_km':
            case '-odometer_km':
                $sortByCol = 'odometer_km';
                $sortByDirection = ($sortBy === 'odometer_km') ? 'DESC' : 'ASC';
                break;
            case 'odometer_mile':
            case '-odometer_mile':
                $sortByCol = 'odometer_mile';
                $sortByDirection = ($sortBy === 'odometer_mile') ? 'DESC' : 'ASC';
                break;
            case 'power':
            case '-power':
                $sortByCol = 'power';
                $sortByDirection = ($sortBy === 'power') ? 'DESC' : 'ASC';
                break;
            case 'model_year':
            case '-model_year':
                $sortByCol = 'model_year';
                $sortByDirection = ($sortBy === 'model_year') ? 'DESC' : 'ASC';
                break;
            case 'id':
            case '-id':
                $sortByCol = 'id';
                $sortByDirection = ($sortBy === 'id') ? 'DESC' : 'ASC';
                break;

            default:
                break;
        }

        //echo "<pre>";print_r([$sortByCol => $sortByDirection]);echo "</pre>";die('Call');
        //echo "<pre>";print_r($sortByDirection);echo "</pre>";
        //echo "<pre>";print_r($sortByCol);echo "</pre>";die('Call');
        //echo "<pre>";print_r("{$sortByCol} {$sortByDirection}");echo "</pre>";die('Call');
        $query = Vehicle::find()->where(['status' => Vehicle::PUBLISHED])->orderBy("{$sortByCol} {$sortByDirection}");
        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,

        ]);



        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'id' => $this->id,
            'user_id' => $this->user_id,
            'phone_number' => $this->phone_number,
            'status' => $this->status,
            'owner_id' => $this->owner_id,
            'owner_type_id' => $this->owner_type_id,
            'is_featured' => $this->is_featured,
            'price' => $this->price,
            'vehicle_type' => $this->vehicle_type,
            'model_year' => $this->model_year,
            'odometer_km' => $this->odometer_km,
            'odometer_mile' => $this->odometer_mile,
            'front_left_status' => $this->front_left_status,
            'front_right_status' => $this->front_right_status,
            'back_left_status' => $this->back_left_status,
            'back_right_status' => $this->back_right_status,
            'body_type_id' => $this->body_type_id,
            'cylinders_id' => $this->cylinders_id,
            'capacity' => $this->capacity,
            'engine_id' => $this->engine_id,
            'power' => $this->power,
            'rim_size' => $this->rim_size,
            'transmission_id' => $this->transmission_id,
            'drive_id' => $this->drive_id,
            'image_counter' => $this->image_counter,
            'manufacturer_id' => $this->manufacturer_id,
            'measuring_the_distance_id' => $this->measuring_the_distance_id,
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
            'approved_at' => $this->approved_at,
            'created_by' => $this->created_by,
            'updated_by' => $this->updated_by,
            'manufacturer_model_id' => $this->manufacturer_model_id,
            'is_sold' => $this->is_sold,
            'car_type' => $this->car_type,
            'is_accidental' => $this->is_accidental,
            'sell_as' => $this->sell_as
        ]);

        $query->andFilterWhere(['like', 'full_name', $this->full_name])
            ->andFilterWhere(['like', 'email', $this->email])
            ->andFilterWhere(['like', 'slug', $this->slug])
            ->andFilterWhere(['like', 'title', $this->title])
            ->andFilterWhere(['like', 'color_id', $this->color_id])
            ->andFilterWhere(['like', 'interior_color_id', $this->interior_color_id])
            ->andFilterWhere(['like', 'video_file', $this->video_file])
            ->andFilterWhere(['like', 'carseer_url', $this->carseer_url])
            ->andFilterWhere(['like', 'image360', $this->image360])
            ->andFilterWhere(['like', 'phone', $this->phone])
            ->andFilterWhere(['like', 'other_information', $this->other_information]);

        if($this->equipment){
            $vehicle_equipment_ids = ArrayHelper::getColumn(VehicleEquipment::find()->where(['equipment_id'=>$this->equipment])->all(),'vehicle_id');
            $query->andFilterWhere(['in','id',$vehicle_equipment_ids]);
        }

        if(!empty($this->price_from) && !empty($this->price_to)){
            $query->andWhere(['BETWEEN', 'price', $this->price_from, $this->price_to]);
        }else{
            if ($this->price_from) {
                $query->andFilterWhere(['>=','price', $this->price_from]);
            }
            if ($this->price_to) {
                $query->andFilterWhere(['<=','price', $this->price_to]);
            }
        }

        if(!empty($this->distance_km_from) && !empty($this->distance_km_to)){
            $query->andWhere(['BETWEEN', 'odometer_km', $this->distance_km_from, $this->distance_km_to]);
        }else{
            if ($this->distance_km_from) {
                $query->andFilterWhere(['>=','odometer_km', $this->distance_km_from]);
            }
            if ($this->distance_km_to) {
                $query->andFilterWhere(['<=','odometer_km', $this->distance_km_to]);
            }
        }


        if(!empty($this->distance_mile_from) && !empty($this->distance_mile_to)){
            $query->andWhere(['BETWEEN', 'odometer_mile', $this->distance_mile_from, $this->distance_mile_to]);
        }else{
            if ($this->distance_mile_from) {
                $query->andFilterWhere(['>=','odometer_mile', $this->distance_mile_from]);
            }
            if ($this->distance_mile_to) {
                $query->andFilterWhere(['<=','odometer_mile', $this->distance_mile_to]);
            }
        }

        if(!empty($this->keyword)){
            $vehicle_keyword_ids = ArrayHelper::getColumn(VehicleLang::find()->where(['like', 'title', $this->keyword])->all(),'parent_id');
            $query->andFilterWhere(['in','id',$vehicle_keyword_ids]);
        }
        //echo "<pre>";print_r($dataProvider->query->createCommand()->getRawSql());echo "</pre>";die('Call');


        return $dataProvider;
    }

    public function backendSearch($params)
    {
        $query = Vehicle::find();

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
        ]);

        $this->load($params,'');

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'id' => $this->id,
            'user_id' => $this->user_id,
            'phone_number' => $this->phone_number,
            'status' => $this->status,
            'owner_id' => $this->owner_id,
            'owner_type_id' => $this->owner_type_id,
            'is_featured' => $this->is_featured,
            'price' => $this->price,
            'vehicle_type' => $this->vehicle_type,
            'model_year' => $this->model_year,
            'odometer_km' => $this->odometer_km,
            'odometer_mile' => $this->odometer_mile,
            'front_left_status' => $this->front_left_status,
            'front_right_status' => $this->front_right_status,
            'back_left_status' => $this->back_left_status,
            'back_right_status' => $this->back_right_status,
            'body_type_id' => $this->body_type_id,
            'cylinders_id' => $this->cylinders_id,
            'capacity' => $this->capacity,
            'engine_id' => $this->engine_id,
            'power' => $this->power,
            'rim_size' => $this->rim_size,
            'transmission_id' => $this->transmission_id,
            'drive_id' => $this->drive_id,
            'image_counter' => $this->image_counter,
            'manufacturer_id' => $this->manufacturer_id,
            'measuring_the_distance_id' => $this->measuring_the_distance_id,
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
            'approved_at' => $this->approved_at,
            'created_by' => $this->created_by,
            'updated_by' => $this->updated_by,
            'manufacturer_model_id' => $this->manufacturer_model_id,
            'is_sold' => $this->is_sold,
            'car_type' => $this->car_type,
            'is_accidental' => $this->is_accidental,
            'sell_as' => $this->sell_as
        ]);

        $query->andFilterWhere(['like', 'full_name', $this->full_name])
            ->andFilterWhere(['like', 'email', $this->email])
            ->andFilterWhere(['like', 'slug', $this->slug])
            ->andFilterWhere(['like', 'title', $this->title])
            ->andFilterWhere(['like', 'color_id', $this->color_id])
            ->andFilterWhere(['like', 'interior_color_id', $this->interior_color_id])
            ->andFilterWhere(['like', 'video_file', $this->video_file])
            ->andFilterWhere(['like', 'carseer_url', $this->carseer_url])
            ->andFilterWhere(['like', 'image360', $this->image360])
            ->andFilterWhere(['like', 'phone', $this->phone])
            ->andFilterWhere(['like', 'other_information', $this->other_information]);

        return $dataProvider;
    }
}
