<?php
use yii\web\Request;
$params = array_merge(
    require __DIR__ . '/../../common/config/params.php',
    require __DIR__ . '/../../common/config/params-local.php',
    require __DIR__ . '/params.php',
    require __DIR__ . '/params-local.php'
);
$baseUrl = str_replace('/frontend/web', '', (new Request)->getBaseUrl());
return [
    'id' => 'app-frontend',
    'language' => \backend\modules\translatemanager\models\Language::DEFAULT_LANGUAGE,
    'basePath' => dirname(__DIR__),
    'bootstrap' => ['log','language', 'translatemanager'],
    'on beforeRequest' => function ($event) {

        $language = Yii::$app->getRequest()->getCookies()->getValue('language') ?:
        backend\modules\translatemanager\models\Language::DEFAULT_LANGUAGE;
        Yii::$app->language = $language;
    },
    'controllerNamespace' => 'frontend\controllers',
    'components' => [
        'mobileDetect' => array(
            'class' => 'ext.MobileDetect.MobileDetect'
        ),
        'request' => [
            'baseUrl' => $baseUrl,
            'csrfParam' => '_csrf-frontend',
        ],
        'assetManager' => [
            'bundles' => [
                'yii\bootstrap\BootstrapPluginAsset' => ['js'=>[]],
                'yii\bootstrap\BootstrapAsset' => ['css' => []]
            ]
        ],
        'user' => [
            'identityClass' => 'common\models\Users',
            'enableAutoLogin' => true,
            'identityCookie' => ['name' => '_identity-frontend', 'httpOnly' => true],
        ],
        'translatemanager' => [
            'class' => 'lajax\translatemanager\Component'
        ],

        'reCaptcha' => [
            'name' => 'reCaptcha',
            'class' => 'himiklab\yii2\recaptcha\ReCaptcha',
            'siteKey' => '6LcVJGYUAAAAAGTGaIRa6uARNyd2kc4RU3XQNgLZ',
            'secret' => '6LcVJGYUAAAAAOKLVjxq0Y4pFCdsbj1qnirmcCBr',
        ],
        'session' => [
            // this is the name of the session cookie used for login on the frontend
            'name' => 'advanced-frontend',
        ],
        'log' => [
            'traceLevel' => YII_DEBUG ? 3 : 0,
            'targets' => [
                [
                    'class' => 'yii\log\FileTarget',
                    'levels' => ['error', 'warning'],
                ],
            ],
        ],
        'language' => [
            'class'=>\frontend\components\Language::class
        ],
        'errorHandler' => [
            'errorAction' => 'site/error',
        ],

        'urlManager' => [
            'baseUrl' => $baseUrl,
            'enablePrettyUrl' => true,
            'showScriptName' => false,
            'rules' => [
                [
                    'pattern' => 'page/<slug>',
                    'route' => 'page/index',
                    'defaults' => ['slug' => ''],
                ],
                [
                    'pattern' => 'step-to-listing/<slug>',
                    'route' => 'site/step-to-listing',
                    'defaults' => ['slug' => ''],
                ],
                [
                    'pattern' => 'listing/<slug>',
                    'route' => 'site/listing',
                    'defaults' => ['slug' => ''],
                ],
                [
                    'pattern' => 'edit-listing/<slug>',
                    'route' => 'site/edit-listing',
                    'defaults' => ['slug' => ''],
                ],
                [
                    'pattern' => 'bid/<slug>',
                    'route' => 'site/bid',
                    'defaults' => ['slug' => ''],
                ],
                [
                    'pattern' => 'cardetail/<slug>',
                    'route' => 'site/cardetail',
                    'defaults' => ['slug' => ''],
                ],
                [
                    'pattern' => 'testpay/<id>',
                    'route' => 'site/testpay',
                    'defaults' => ['id' => ''],
                ],

                'car-detail'=>'site/car-detail',
                'test'=>'site/test',
            ],
        ],
        'urlManagerBackEnd' => [

            'class' => 'yii\web\urlManager',

            'baseUrl' => 'https://admin.oto.jo',
            'enablePrettyUrl' => false,

            'showScriptName' => false,
        ],

        'authClientCollection' => [

            'class' => 'yii\authclient\Collection',

            'clients' => [
                'facebook' => require_once 'authclient-facebook.php',
                'google' => require_once 'authclient-google.php',
             ],
            ]
    ],
    'params' => $params,
];





