<?php

namespace frontend\models;

use common\models\Users;
use yii\base\InvalidArgumentException;
use yii\base\Model;
use Yii;
use common\models\User;

/**
 * Password reset form
 */
class ChangePasswordForm extends Model
{
    public $old_password;
    public $new_password;
    public $confirm_password;

    /**
     * @var \common\models\User
     */
    private $_user;

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['old_password'],'required', 'when' => function(){
                return !empty(Yii::$app->user->identity->password);
            }],
            [[ 'new_password', 'confirm_password'],'required'],
            ['confirm_password', 'compare', 'compareAttribute'=>'new_password', 'message'=>  Yii::t('auto', "Passwords don't match")],
            ['new_password', 'string', 'min' => Yii::$app->params['user.passwordMinLength'], 'tooShort' => Yii::t('auto', 'Password should contain at least {min} characters.')],
            [['old_password'], 'validatePassword'],
            [['new_password'], 'samePassword'],
            ['new_password', 'match',
                //'pattern' => '/^(?=.*[0-9])(?=.*[A-Z])([a-zA-Z0-9]+)$/',
                'pattern' => '/^(?=.*[A-Za-z])(?=.*\d)(?=.*[_@$!%*#?&])[A-Za-z\d_@$!%*#?&]{6,}$/',
                'message' => Yii::t('auto','Password must have minimum six characters, at least one letter, one number and one special character'),
            ],
        ];
    }


    /**
     * Validates password
     *
     * @param string $password password to validate
     * @return bool if password provided is valid for current user
     */
    public function validatePassword()
    {
        if(!empty(Yii::$app->user->identity->password)){
            $passwordValidated = Yii::$app->security->validatePassword($this->old_password, Yii::$app->user->identity->password);
            if(!$passwordValidated){
                $this->addError('old_password',Yii::t('auto', 'Old password is not correct'));
            }
        }
    }

    public function samePassword(){
        if(!empty(Yii::$app->user->identity->password)){
            $password_exists = Yii::$app->security->validatePassword($this->new_password,   Yii::$app->user->identity->password);
            if($password_exists){
                $this->addError('new_password',Yii::t('auto', 'New password same as old password'));
            }
        }

    }

}
